<?php
class TP_yyToken implements ArrayAccess
{
    public $string = '';
    public $metadata = array();

    public function __construct($s, $m = array())
    {
        if ($s instanceof TP_yyToken) {
            $this->string = $s->string;
            $this->metadata = $s->metadata;
        } else {
            $this->string = (string) $s;
            if ($m instanceof TP_yyToken) {
                $this->metadata = $m->metadata;
            } elseif (is_array($m)) {
                $this->metadata = $m;
            }
        }
    }

    public function __toString()
    {
        return $this->string;
    }

    public function offsetExists($offset)
    {
        return isset($this->metadata[$offset]);
    }

    public function offsetGet($offset)
    {
        return $this->metadata[$offset];
    }

    public function offsetSet($offset, $value)
    {
        if ($offset === null) {
            if (isset($value[0])) {
                $x = ($value instanceof TP_yyToken) ?
                    $value->metadata : $value;
                $this->metadata = array_merge($this->metadata, $x);

                return;
            }
            $offset = count($this->metadata);
        }
        if ($value === null) {
            return;
        }
        if ($value instanceof TP_yyToken) {
            if ($value->metadata) {
                $this->metadata[$offset] = $value->metadata;
            }
        } elseif ($value) {
            $this->metadata[$offset] = $value;
        }
    }

    public function offsetUnset($offset)
    {
        unset($this->metadata[$offset]);
    }
}

class TP_yyStackEntry
{
    public $stateno;       /* The state-number */
    public $major;         /* The major token value.  This is the code
                     ** number for the token at this stack level */
    public $minor; /* The user-supplied minor token value.  This
                     ** is the value of the token  */
};


#line 11 "./lexer/smarty_internal_templateparser.y"

/**
* Smarty Template Parser Class
*
* This is the template parser.
* It is generated from the smarty_internal_templateparser.y file
* 
* @author Uwe Tews <uwe.tews@googlemail.com>
*/
class Smarty_Internal_Templateparser
{
#line 23 "./lexer/smarty_internal_templateparser.y"

    const Err1 = "Security error: Call to private object member not allowed";
    const Err2 = "Security error: Call to dynamic object member not allowed";
    const Err3 = "PHP in template not allowed. Use SmartyBC to enable it";

    /**
     * result status
     *
     * @var bool
     */
    public $successful = true;

    /**
     * return value
     *
     * @var mixed
     */
    public $retvalue = 0;

    /**
     * counter for prefix code
     *
     * @var int
     */
    public static $prefix_number = 0;

    /**
     * @var
     */
    public $yymajor;

    /**
     * last index of array variable
     *
     * @var mixed
     */
    public $last_index;

    /**
     * last variable name
     *
     * @var string
     */
    public $last_variable;

    /**
     * root parse tree buffer
     *
     * @var Smarty_Internal_ParseTree
     */
    public $root_buffer;

    /**
     * current parse tree object
     *
     * @var Smarty_Internal_ParseTree
     */
    public $current_buffer;

    /**
     * lexer object
     *
     * @var Smarty_Internal_Templatelexer
     */
    public $lex;

    /**
     * internal error flag
     *
     * @var bool
     */
    private $internalError = false;

    /**
     * {strip} status
     *
     * @var bool
     */
    public $strip = false;
    /**
     * compiler object
     *
     * @var Smarty_Internal_TemplateCompilerBase
     */
    public $compiler = null;

    /**
     * smarty object
     *
     * @var Smarty
     */
    public $smarty = null;

    /**
     * template object
     *
     * @var Smarty_Internal_Template
     */
    public $template = null;

    /**
     * block nesting level
     *
     * @var int
     */
    public $block_nesting_level = 0;

    /**
     * security object
     *
     * @var Smarty_Security
     */
    public $security = null;

    /**
     * template prefix array
     *
     * @var \Smarty_Internal_ParseTree[]
     */
    public $template_prefix = array();

    /**
     * security object
     *
     * @var \Smarty_Internal_ParseTree[]
     */
    public $template_postfix = array();

    /**
     * constructor
     *
     * @param Smarty_Internal_Templatelexer        $lex
     * @param Smarty_Internal_TemplateCompilerBase $compiler
     */
    function __construct(Smarty_Internal_Templatelexer $lex, Smarty_Internal_TemplateCompilerBase $compiler)
    {
        $this->lex = $lex;
        $this->compiler = $compiler;
        $this->template = $this->compiler->template;
        $this->smarty = $this->template->smarty;
        $this->security = isset($this->smarty->security_policy) ? $this->smarty->security_policy : false;
        $this->current_buffer = $this->root_buffer = new Smarty_Internal_ParseTree_Template();
    }

    /**
     * insert PHP code in current buffer
     *
     * @param string $code
     */
    public function insertPhpCode($code)
    {
        $this->current_buffer->append_subtree($this, new Smarty_Internal_ParseTree_Tag($this, $code));
    }

   /**
     *  merge PHP code with prefix code and return parse tree tag object
     *
     * @param string $code
     *
     * @return Smarty_Internal_ParseTree_Tag
     */
    public function mergePrefixCode($code)
    {
        $tmp ='';
        foreach ($this->compiler->prefix_code as $preCode) {
            $tmp .= $preCode;
        }
        $this->compiler->prefix_code=array();
        $tmp .= $code;
        return new Smarty_Internal_ParseTree_Tag($this, $this->compiler->processNocacheCode($tmp,true));
    }


    const TP_VERT                           =  1;
    const TP_COLON                          =  2;
    const TP_PHP                            =  3;
    const TP_NOCACHE                        =  4;
    const TP_TEXT                           =  5;
    const TP_STRIPON                        =  6;
    const TP_STRIPOFF                       =  7;
    const TP_LITERALSTART                   =  8;
    const TP_LITERALEND                     =  9;
    const TP_LITERAL                        = 10;
    const TP_RDEL                           = 11;
    const TP_SIMPELOUTPUT                   = 12;
    const TP_LDEL                           = 13;
    const TP_DOLLARID                       = 14;
    const TP_EQUAL                          = 15;
    const TP_SIMPLETAG                      = 16;
    const TP_ID                             = 17;
    const TP_PTR                            = 18;
    const TP_LDELIF                         = 19;
    const TP_LDELFOR                        = 20;
    const TP_SEMICOLON                      = 21;
    const TP_INCDEC                         = 22;
    const TP_TO                             = 23;
    const TP_STEP                           = 24;
    const TP_LDELFOREACH                    = 25;
    const TP_SPACE                          = 26;
    const TP_AS                             = 27;
    const TP_APTR                           = 28;
    const TP_LDELSETFILTER                  = 29;
    const TP_SMARTYBLOCKCHILDPARENT         = 30;
    const TP_CLOSETAG                       = 31;
    const TP_LDELSLASH                      = 32;
    const TP_ATTR                           = 33;
    const TP_INTEGER                        = 34;
    const TP_COMMA                          = 35;
    const TP_OPENP                          = 36;
    const TP_CLOSEP                         = 37;
    const TP_MATH                           = 38;
    const TP_UNIMATH                        = 39;
    const TP_ISIN                           = 40;
    const TP_INSTANCEOF                     = 41;
    const TP_QMARK                          = 42;
    const TP_NOT                            = 43;
    const TP_TYPECAST                       = 44;
    const TP_HEX                            = 45;
    const TP_DOT                            = 46;
    const TP_SINGLEQUOTESTRING              = 47;
    const TP_DOUBLECOLON                    = 48;
    const TP_NAMESPACE                      = 49;
    const TP_AT                             = 50;
    const TP_HATCH                          = 51;
    const TP_OPENB                          = 52;
    const TP_CLOSEB                         = 53;
    const TP_DOLLAR                         = 54;
    const TP_LOGOP                          = 55;
    const TP_TLOGOP                         = 56;
    const TP_SINGLECOND                     = 57;
    const TP_QUOTE                          = 58;
    const TP_BACKTICK                       = 59;
    const YY_NO_ACTION = 527;
    const YY_ACCEPT_ACTION = 526;
    const YY_ERROR_ACTION = 525;

    const YY_SZ_ACTTAB = 1968;
static public $yy_action = array(
    252,    8,  130,  259,  238,  195,  184,    4,   83,  326,
     24,  199,  297,  113,  325,   36,  273,  226,   16,  282,
    216,  399,  205,   23,   28,  172,  442,   43,  179,  188,
     17,   41,   39,  302,  228,  234,  399,  208,  442,   81,
      1,  315,  327,  399,  303,  220,   53,  252,    8,  131,
    180,  238,   75,  217,    4,   83,  314,  255,  256,  232,
    113,  353,  218,   52,  226,  301,  282,  216,  221,  236,
    215,   28,  303,  104,   43,  320,   23,   20,   41,   39,
    302,  228,  306,   17,  208,  291,   81,    1,  250,  327,
    218,   52,  121,   53,  252,    8,  133,  100,  238,  193,
      3,    4,   83,  328,  243,  182,  313,  113,  323,  135,
     99,  226,   94,  282,  216,   10,  200,  138,   28,   15,
    442,   43,   27,   84,  289,   41,   39,  302,  228,  306,
    214,  208,  442,   81,    1,    2,  327,  307,  135,   93,
     53,  252,    8,  133,   10,  238,  210,  112,    4,   83,
    235,  144,  148,  455,  113,  293,   91,  327,  226,  455,
    282,  216,  245,  236,   29,   28,  303,   99,   43,   32,
     23,  309,   41,   39,  302,  228,  306,   17,  208,  188,
     81,    1,  229,  327,  251,   52,  121,   53,  252,    8,
    133,  100,  238,  191,  176,    4,   83,  107,  251,  164,
    455,  113,  323,   92,  122,  226,  455,  282,  216,  245,
    236,  221,   28,  213,  201,   43,  104,  188,  304,   41,
     39,  302,  228,  306,  327,  208,  188,   81,    1,  153,
    327,  140,  303,   14,   53,  252,    8,  133,  327,  238,
    210,  245,    4,   83,  326,   24,  156,   90,  113,  325,
    175,   52,  226,  324,  282,  216,  245,  192,   22,   28,
    303,   99,   43,  181,  267,  271,   41,   39,  302,  228,
    306,   23,  208,  188,   81,    1,  246,  327,   17,   52,
    443,   53,  252,    8,  132,   99,  238,  210,  142,    4,
     83,  107,  443,  168,   32,  113,  305,  292,  245,  226,
    199,  282,  216,  245,  236,   21,   28,  189,    6,   43,
    324,  316,  253,   41,   39,  302,  228,  306,  291,  208,
    189,   81,    1,  218,  327,   23,  285,  175,   53,  252,
      8,  133,   17,  238,  196,  235,    4,   83,  221,   32,
    275,  310,  113,  104,  199,  170,  226,  442,  282,  216,
    188,  236,  143,   28,  324,  245,   43,  298,  247,  442,
     41,   39,  302,  228,  306,  119,  208,  324,   81,    1,
    105,  327,  173,  185,  313,   53,  252,    8,  129,  235,
    238,  210,  245,    4,   83,  287,  318,  159,  151,  113,
    324,  158,  119,  226,  324,  282,  216,  245,  236,  270,
      5,  245,  268,   43,  183,  313,  199,   41,   39,  302,
    228,  306,  137,  208,  189,   81,    1,  102,  327,   99,
    199,  171,   53,  252,    8,  134,  104,  238,  210,  165,
      4,   83,  199,   19,  321,  254,  113,  233,  155,  245,
    226,  160,  282,  216,  178,  236,   34,   11,  245,  107,
     43,  245,  327,   17,   41,   39,  302,  228,  306,  174,
    208,  294,   81,    1,   89,  327,  177,  188,  157,   53,
    252,    8,  134,  134,  238,  210,  249,    4,   83,  199,
     38,  150,  188,  113,  265,  199,  279,  226,  303,  282,
    216,  317,  236,   31,   11,  359,  212,   43,  269,  304,
    109,   41,   39,  302,  228,  306,  272,  208,  248,   81,
     81,    3,  327,  327,  471,  471,   53,  296,   25,  471,
    257,  258,  260,  261,  262,  181,  199,  471,  471,  252,
      8,   29,  471,  238,    7,  263,    4,   83,  237,  322,
    218,  209,  113,  115,   72,  108,  226,  329,  282,  216,
    100,   85,  471,  330,  241,  326,   24,  207,  319,  242,
    325,  323,  280,   42,   40,   37,  187,  286,  263,  154,
     82,  206,  283,  218,  209,   38,  115,   72,  108,  328,
    266,  239,  240,  100,  277,  145,  330,  241,  149,  136,
    207,  319,  242,  223,  323,  299,  471,  471,  263,  324,
    152,  471,  455,  218,  209,  284,  120,   69,  108,  117,
     42,   40,   37,  100,   86,  199,  330,  241,   88,   87,
    207,  319,  242,  299,  323,  396,  299,  266,  239,  240,
    455,  204,  455,  263,  471,  199,  455,  299,  218,  209,
    396,  120,   69,  108,  299,  399,  299,  396,  100,   26,
    224,  330,  241,  146,  299,  207,  319,  242,  299,  323,
    399,  139,  299,  263,  299,  299,  202,  399,  218,  209,
    299,  120,   46,  106,  299,  111,  299,  299,  100,  326,
     24,  330,  241,  299,  325,  207,  319,  242,  299,  323,
    327,  299,  299,   23,  299,  141,  263,  299,  299,  299,
     17,  218,  209,  299,  120,   55,  106,  299,  215,  299,
    299,  100,  299,  299,  330,  241,  299,  299,  207,  319,
    242,  263,  323,  299,  166,  299,  218,  209,  184,  120,
     69,  108,  299,  299,  245,  299,  100,   36,  273,  330,
    241,  299,  299,  207,  319,  242,  299,  323,  299,  299,
    263,  188,  299,  163,  203,  218,  209,  184,  120,   76,
    108,  199,  299,  245,  299,  100,   36,  273,  330,  241,
    299,  365,  207,  319,  242,  299,  323,  299,  230,  263,
    188,  299,  299,  299,  218,  209,   23,  120,   49,  108,
    299,  299,  299,   17,  100,  299,  442,  330,  241,  299,
    299,  207,  319,  242,  263,  323,  326,   24,  442,  218,
    198,  325,  114,   57,  108,  326,   24,  299,  299,  100,
    325,  199,  330,  241,  299,  299,  207,  319,  242,   23,
    323,  355,  299,  263,  299,  299,   17,  299,  218,  209,
    299,   97,   62,  108,  219,  299,   23,  299,  100,  299,
    299,  330,  241,   17,  397,  207,  319,  242,  222,  323,
    299,  134,  263,  299,  227,  299,  299,  218,   96,  397,
     80,   44,  103,  299,  299,  299,  397,  100,  299,  442,
    330,  241,  299,  299,  207,  319,  242,  263,  323,  299,
    299,  442,  218,  209,  299,  120,   47,  108,   81,  299,
    299,  327,  100,  299,  299,  330,  241,  299,  299,  207,
    319,  242,  299,  323,  299,  299,  263,  299,  299,  299,
    299,  218,   95,  299,   80,   50,  103,  299,  299,  299,
    299,  100,  299,  299,  330,  241,  299,  299,  207,  319,
    242,  299,  323,  299,  299,  263,  299,  299,  299,  299,
    218,  209,  299,  120,   67,  108,  299,  299,  299,  299,
    100,  299,  299,  330,  241,  299,  299,  207,  319,  242,
    263,  323,  299,  299,  299,  218,  209,  299,  120,   77,
    108,  299,  299,   30,  194,  100,  299,  312,  330,  241,
    299,  290,  207,  319,  242,  299,  323,  299,  252,    9,
    281,  299,  238,  299,  311,    4,   83,  299,  299,  299,
    299,  113,  290,  299,  299,  226,  299,  282,  216,  252,
      9,  281,  299,  238,  327,  263,    4,   83,  299,  299,
    218,  211,  113,  127,  299,  108,  226,  299,  282,  216,
    100,  299,  169,  299,  299,   18,  184,  207,  319,  242,
    299,  323,  245,  263,  299,   36,  273,  299,  218,  209,
    299,  120,   63,  108,  299,  300,   18,  299,  100,  188,
    299,  330,  241,  299,  299,  207,  319,  242,  299,  323,
    263,  299,  299,  161,  299,  218,  209,  184,  120,   78,
    108,  299,  299,  245,  299,  100,   36,  273,  330,  241,
    299,  299,  207,  319,  242,  299,  323,  299,  299,  263,
    188,  199,  167,  299,  218,  209,  184,  116,   48,  108,
    299,  244,  245,  299,  100,   36,  273,  330,  241,  299,
    299,  207,  319,  242,  299,  323,  263,  299,  299,  188,
    299,  218,  209,  299,  101,   65,  108,  299,   42,   40,
     37,  100,  299,  299,  330,  241,  299,  299,  207,  319,
    242,  299,  323,  263,  299,  266,  239,  240,  218,  209,
    299,   98,   73,  108,  299,  299,  299,  299,  100,  299,
    299,  330,  241,  299,  299,  207,  319,  242,  299,  323,
    299,  299,  263,  299,  199,  299,  299,  218,  209,  299,
    120,   64,  108,  299,  186,  299,  299,  100,  299,  299,
    330,  241,  299,  299,  207,  319,  242,  299,  323,  263,
    299,  299,  299,  299,  218,  209,  299,  120,   66,  108,
    299,   42,   40,   37,  100,  299,  299,  330,  241,  299,
    299,  207,  319,  242,  299,  323,  263,  299,  266,  239,
    240,  218,  209,  299,  120,   58,  108,  299,  299,  299,
    299,  100,  299,  299,  330,  241,  299,  299,  207,  319,
    242,  299,  323,  299,  299,  263,  299,  199,  299,  299,
    218,  209,  299,  120,   45,  108,  299,  190,  299,  299,
    100,  299,  299,  330,  241,  299,  299,  207,  319,  242,
    299,  323,  263,  299,  299,  299,  299,  218,  197,  299,
    120,   54,  108,  299,   42,   40,   37,  100,  299,  299,
    330,  241,  299,  299,  207,  319,  242,  299,  323,  263,
    299,  266,  239,  240,  218,  209,  299,  120,   60,  108,
    299,  299,  299,  299,  100,  299,  299,  330,  241,  299,
    299,  207,  319,  242,  299,  323,  299,  299,  263,  299,
    199,   35,  299,  218,  209,  299,  120,   59,  108,  299,
    299,  299,  299,  100,  299,  299,  330,  241,  299,  299,
    207,  319,  242,  299,  323,  263,  299,  299,  299,  299,
    218,  209,  299,  120,   70,  108,  299,   42,   40,   37,
    100,  299,  299,  330,  241,  299,  299,  207,  319,  242,
    299,  323,  263,  299,  266,  239,  240,  218,  209,  299,
    120,   79,  108,  299,  299,  299,  299,  100,  299,  299,
    330,  241,  299,  299,  207,  319,  242,  299,  323,  299,
    299,  263,  299,  199,  299,  299,  218,  209,  299,  120,
     55,  108,  299,  308,  299,  299,  100,  299,  299,  330,
    241,  299,  299,  207,  319,  242,  299,  323,  263,  299,
    299,  299,  299,  218,  209,  299,  120,   74,  108,  299,
     42,   40,   37,  100,  299,  299,  330,  241,  299,  299,
    207,  319,  242,  299,  323,  263,  299,  266,  239,  240,
    218,  209,  299,  120,   68,  108,  299,  299,  299,  299,
    100,  299,  299,  330,  241,  299,  299,  207,  319,  242,
    299,  323,  299,  299,  263,  299,  199,  299,  299,  218,
    209,  299,  120,   56,  108,  299,  299,  299,  299,  100,
    299,  299,  330,  241,  299,  299,  207,  319,  242,  299,
    323,  263,  299,  299,  299,  299,  218,  209,  299,  120,
     61,  108,  231,   42,   40,   37,  100,  299,  299,  330,
    241,  299,  299,  207,  319,  242,  299,  323,  263,  299,
    266,  239,  240,  218,  209,  299,  120,   71,  108,  299,
    299,  299,  299,  100,  299,  299,  330,  241,  299,  299,
    207,  319,  242,  299,  323,  299,  299,  263,  299,  299,
    299,  299,  218,  211,  299,  118,  299,  108,  299,  299,
    299,  299,  100,  299,  299,  299,  264,  299,  299,  207,
    319,  242,  199,  323,  263,  299,  199,  299,  299,  218,
    211,  199,  128,  299,  108,  299,  409,  409,  299,  100,
    299,  299,  110,  278,  299,  299,  207,  319,  242,   33,
    323,   23,  299,  299,  299,  299,  299,  299,   17,   42,
     40,   37,  299,   42,   40,   37,  299,  299,   42,   40,
     37,  442,  299,  409,  409,  409,  266,  239,  240,  299,
    266,  239,  240,  442,  225,  266,  239,  240,  299,  295,
    409,  409,  409,  225,  471,  471,  299,   27,  299,  471,
    455,  299,  225,  471,  471,  299,  299,  299,  471,  455,
    299,  299,  471,  471,  403,   12,  299,  471,  455,  199,
    299,  299,  299,  299,  403,  299,  403,  299,  455,  403,
    455,  299,  471,  299,  455,  299,  403,  455,  403,  455,
    403,  471,  299,  455,  274,  199,  455,  299,  455,  235,
    471,  299,  455,  299,  299,  288,   42,   40,   37,  526,
     51,  331,  255,  256,  232,  299,  299,  218,  299,  299,
     23,  276,  299,  266,  239,  240,  299,   17,  299,  299,
    263,  299,   42,   40,   37,  218,  211,  299,  123,  299,
    108,  299,  299,  299,  299,  100,  299,  299,  299,  266,
    239,  240,  207,  319,  242,  299,  323,  299,  299,  263,
    299,  299,  225,  299,  218,  211,  299,  126,  299,  108,
    299,  299,  471,  471,  100,  299,  299,  471,  455,  299,
    299,  207,  319,  242,  299,  323,  299,  299,  299,  299,
    299,  299,  263,  299,  299,  299,  299,  218,  211,  199,
    124,  299,  108,  299,  299,  299,  455,  100,  455,  299,
    471,  299,  455,  299,  207,  319,  242,  263,  323,   13,
    199,  299,  218,  211,   23,  125,  299,  108,  299,  471,
    471,   17,  100,  199,  471,  455,   42,   40,   37,  207,
    319,  242,  299,  323,  299,  299,  147,  299,  299,  299,
    299,  299,  299,  266,  239,  240,  299,   42,   40,   37,
    299,  299,  299,  455,  299,  455,  299,  471,  299,  455,
     42,   40,   37,  299,  266,  239,  240,  299,  299,  299,
    162,  299,  299,  299,  184,  299,  299,  266,  239,  240,
    245,  299,  299,   36,  273,  299,  299,  299,  299,  299,
    299,  299,  299,  299,  299,  299,  299,  188,
    );
    static public $yy_lookahead = array(
     12,   13,   14,    5,   16,   17,   75,   19,   20,   12,
     13,    1,   17,   25,   17,   84,   85,   29,   28,   31,
     32,   11,   34,   26,   36,   28,   36,   39,   80,   98,
     33,   43,   44,   45,   46,   47,   26,   49,   48,   51,
     52,   53,   54,   33,   22,   50,   58,   12,   13,   14,
     14,   16,   17,   17,   19,   20,   63,   64,   65,   66,
     25,   11,   69,   41,   29,   30,   31,   32,   74,   34,
     76,   36,   22,   79,   39,   53,   26,   13,   43,   44,
     45,   46,   47,   33,   49,   64,   51,   52,   70,   54,
     69,   41,   74,   58,   12,   13,   14,   79,   16,   17,
     36,   19,   20,   92,   86,   94,   95,   25,   90,   46,
     18,   29,   80,   31,   32,   52,   34,   14,   36,   15,
     36,   39,   15,  102,  103,   43,   44,   45,   46,   47,
     46,   49,   48,   51,   52,   36,   54,   53,   46,   36,
     58,   12,   13,   14,   52,   16,   17,   48,   19,   20,
     46,   91,   71,   46,   25,   11,   75,   54,   29,   52,
     31,   32,   81,   34,   15,   36,   22,   18,   39,   35,
     26,   37,   43,   44,   45,   46,   47,   33,   49,   98,
     51,   52,   70,   54,   14,   41,   74,   58,   12,   13,
     14,   79,   16,   17,   75,   19,   20,   48,   14,   71,
     46,   25,   90,   75,   17,   29,   52,   31,   32,   81,
     34,   74,   36,   76,   77,   39,   79,   98,   99,   43,
     44,   45,   46,   47,   54,   49,   98,   51,   52,   91,
     54,   71,   22,   21,   58,   12,   13,   14,   54,   16,
     17,   81,   19,   20,   12,   13,   71,   35,   25,   17,
     75,   41,   29,   93,   31,   32,   81,   34,   15,   36,
     22,   18,   39,    8,    9,   10,   43,   44,   45,   46,
     47,   26,   49,   98,   51,   52,   95,   54,   33,   41,
     36,   58,   12,   13,   14,   18,   16,   17,   71,   19,
     20,   48,   48,   71,   35,   25,   37,   59,   81,   29,
      1,   31,   32,   81,   34,   15,   36,   98,   35,   39,
     93,   53,   22,   43,   44,   45,   46,   47,   64,   49,
     98,   51,   52,   69,   54,   26,   53,   75,   58,   12,
     13,   14,   33,   16,   17,   46,   19,   20,   74,   35,
     76,   37,   25,   79,    1,   71,   29,   36,   31,   32,
     98,   34,   91,   36,   93,   81,   39,  103,   89,   48,
     43,   44,   45,   46,   47,   96,   49,   93,   51,   52,
     67,   54,   71,   94,   95,   58,   12,   13,   14,   46,
     16,   17,   81,   19,   20,   89,   53,   71,   91,   25,
     93,   71,   96,   29,   93,   31,   32,   81,   34,   65,
     36,   81,   68,   39,   94,   95,    1,   43,   44,   45,
     46,   47,   14,   49,   98,   51,   52,   79,   54,   18,
      1,   74,   58,   12,   13,   14,   79,   16,   17,   71,
     19,   20,    1,   28,   96,    9,   25,   18,   71,   81,
     29,   71,   31,   32,   75,   34,   26,   36,   81,   48,
     39,   81,   54,   33,   43,   44,   45,   46,   47,   75,
     49,   34,   51,   52,   91,   54,   80,   98,   51,   58,
     12,   13,   14,   14,   16,   17,   17,   19,   20,    1,
      2,   91,   98,   25,   53,    1,   17,   29,   22,   31,
     32,   53,   34,   23,   36,   11,   17,   39,   37,   99,
     17,   43,   44,   45,   46,   47,   11,   49,   49,   51,
     51,   36,   54,   54,   12,   13,   58,   17,   42,   17,
      3,    4,    5,    6,    7,    8,    1,   12,   13,   12,
     13,   15,   17,   16,   36,   64,   19,   20,   17,   17,
     69,   70,   25,   72,   73,   74,   29,   17,   31,   32,
     79,   79,   50,   82,   83,   12,   13,   86,   87,   88,
     17,   90,   37,   38,   39,   40,   17,   34,   64,   51,
     17,  100,  101,   69,   70,    2,   72,   73,   74,   92,
     55,   56,   57,   79,   81,   91,   82,   83,   91,   79,
     86,   87,   88,   50,   90,  104,   12,   13,   64,   93,
     91,   17,   18,   69,   70,  101,   72,   73,   74,   78,
     38,   39,   40,   79,   79,    1,   82,   83,   79,   79,
     86,   87,   88,  104,   90,   11,  104,   55,   56,   57,
     46,   97,   48,   64,   50,    1,   52,  104,   69,   70,
     26,   72,   73,   74,  104,   11,  104,   33,   79,   13,
     14,   82,   83,   17,  104,   86,   87,   88,  104,   90,
     26,   27,  104,   64,  104,  104,   97,   33,   69,   70,
    104,   72,   73,   74,  104,   76,  104,  104,   79,   12,
     13,   82,   83,  104,   17,   86,   87,   88,  104,   90,
     54,  104,  104,   26,  104,   28,   64,  104,  104,  104,
     33,   69,   70,  104,   72,   73,   74,  104,   76,  104,
    104,   79,  104,  104,   82,   83,  104,  104,   86,   87,
     88,   64,   90,  104,   71,  104,   69,   70,   75,   72,
     73,   74,  104,  104,   81,  104,   79,   84,   85,   82,
     83,  104,  104,   86,   87,   88,  104,   90,  104,  104,
     64,   98,  104,   71,   97,   69,   70,   75,   72,   73,
     74,    1,  104,   81,  104,   79,   84,   85,   82,   83,
    104,   11,   86,   87,   88,  104,   90,  104,   18,   64,
     98,  104,  104,  104,   69,   70,   26,   72,   73,   74,
    104,  104,  104,   33,   79,  104,   36,   82,   83,  104,
    104,   86,   87,   88,   64,   90,   12,   13,   48,   69,
     70,   17,   72,   73,   74,   12,   13,  104,  104,   79,
     17,    1,   82,   83,  104,  104,   86,   87,   88,   26,
     90,   11,  104,   64,  104,  104,   33,  104,   69,   70,
    104,   72,   73,   74,   50,  104,   26,  104,   79,  104,
    104,   82,   83,   33,   11,   86,   87,   88,   15,   90,
    104,   14,   64,  104,   17,  104,  104,   69,   70,   26,
     72,   73,   74,  104,  104,  104,   33,   79,  104,   36,
     82,   83,  104,  104,   86,   87,   88,   64,   90,  104,
    104,   48,   69,   70,  104,   72,   73,   74,   51,  104,
    104,   54,   79,  104,  104,   82,   83,  104,  104,   86,
     87,   88,  104,   90,  104,  104,   64,  104,  104,  104,
    104,   69,   70,  104,   72,   73,   74,  104,  104,  104,
    104,   79,  104,  104,   82,   83,  104,  104,   86,   87,
     88,  104,   90,  104,  104,   64,  104,  104,  104,  104,
     69,   70,  104,   72,   73,   74,  104,  104,  104,  104,
     79,  104,  104,   82,   83,  104,  104,   86,   87,   88,
     64,   90,  104,  104,  104,   69,   70,  104,   72,   73,
     74,  104,  104,   13,   14,   79,  104,   17,   82,   83,
    104,    5,   86,   87,   88,  104,   90,  104,   12,   13,
     14,  104,   16,  104,   34,   19,   20,  104,  104,  104,
    104,   25,    5,  104,  104,   29,  104,   31,   32,   12,
     13,   14,  104,   16,   54,   64,   19,   20,  104,  104,
     69,   70,   25,   72,  104,   74,   29,  104,   31,   32,
     79,  104,   71,  104,   58,   59,   75,   86,   87,   88,
    104,   90,   81,   64,  104,   84,   85,  104,   69,   70,
    104,   72,   73,   74,  104,   58,   59,  104,   79,   98,
    104,   82,   83,  104,  104,   86,   87,   88,  104,   90,
     64,  104,  104,   71,  104,   69,   70,   75,   72,   73,
     74,  104,  104,   81,  104,   79,   84,   85,   82,   83,
    104,  104,   86,   87,   88,  104,   90,  104,  104,   64,
     98,    1,   71,  104,   69,   70,   75,   72,   73,   74,
    104,   11,   81,  104,   79,   84,   85,   82,   83,  104,
    104,   86,   87,   88,  104,   90,   64,  104,  104,   98,
    104,   69,   70,  104,   72,   73,   74,  104,   38,   39,
     40,   79,  104,  104,   82,   83,  104,  104,   86,   87,
     88,  104,   90,   64,  104,   55,   56,   57,   69,   70,
    104,   72,   73,   74,  104,  104,  104,  104,   79,  104,
    104,   82,   83,  104,  104,   86,   87,   88,  104,   90,
    104,  104,   64,  104,    1,  104,  104,   69,   70,  104,
     72,   73,   74,  104,   11,  104,  104,   79,  104,  104,
     82,   83,  104,  104,   86,   87,   88,  104,   90,   64,
    104,  104,  104,  104,   69,   70,  104,   72,   73,   74,
    104,   38,   39,   40,   79,  104,  104,   82,   83,  104,
    104,   86,   87,   88,  104,   90,   64,  104,   55,   56,
     57,   69,   70,  104,   72,   73,   74,  104,  104,  104,
    104,   79,  104,  104,   82,   83,  104,  104,   86,   87,
     88,  104,   90,  104,  104,   64,  104,    1,  104,  104,
     69,   70,  104,   72,   73,   74,  104,   11,  104,  104,
     79,  104,  104,   82,   83,  104,  104,   86,   87,   88,
    104,   90,   64,  104,  104,  104,  104,   69,   70,  104,
     72,   73,   74,  104,   38,   39,   40,   79,  104,  104,
     82,   83,  104,  104,   86,   87,   88,  104,   90,   64,
    104,   55,   56,   57,   69,   70,  104,   72,   73,   74,
    104,  104,  104,  104,   79,  104,  104,   82,   83,  104,
    104,   86,   87,   88,  104,   90,  104,  104,   64,  104,
      1,    2,  104,   69,   70,  104,   72,   73,   74,  104,
    104,  104,  104,   79,  104,  104,   82,   83,  104,  104,
     86,   87,   88,  104,   90,   64,  104,  104,  104,  104,
     69,   70,  104,   72,   73,   74,  104,   38,   39,   40,
     79,  104,  104,   82,   83,  104,  104,   86,   87,   88,
    104,   90,   64,  104,   55,   56,   57,   69,   70,  104,
     72,   73,   74,  104,  104,  104,  104,   79,  104,  104,
     82,   83,  104,  104,   86,   87,   88,  104,   90,  104,
    104,   64,  104,    1,  104,  104,   69,   70,  104,   72,
     73,   74,  104,   11,  104,  104,   79,  104,  104,   82,
     83,  104,  104,   86,   87,   88,  104,   90,   64,  104,
    104,  104,  104,   69,   70,  104,   72,   73,   74,  104,
     38,   39,   40,   79,  104,  104,   82,   83,  104,  104,
     86,   87,   88,  104,   90,   64,  104,   55,   56,   57,
     69,   70,  104,   72,   73,   74,  104,  104,  104,  104,
     79,  104,  104,   82,   83,  104,  104,   86,   87,   88,
    104,   90,  104,  104,   64,  104,    1,  104,  104,   69,
     70,  104,   72,   73,   74,  104,  104,  104,  104,   79,
    104,  104,   82,   83,  104,  104,   86,   87,   88,  104,
     90,   64,  104,  104,  104,  104,   69,   70,  104,   72,
     73,   74,   37,   38,   39,   40,   79,  104,  104,   82,
     83,  104,  104,   86,   87,   88,  104,   90,   64,  104,
     55,   56,   57,   69,   70,  104,   72,   73,   74,  104,
    104,  104,  104,   79,  104,  104,   82,   83,  104,  104,
     86,   87,   88,  104,   90,  104,  104,   64,  104,  104,
    104,  104,   69,   70,  104,   72,  104,   74,  104,  104,
    104,  104,   79,  104,  104,  104,   83,  104,  104,   86,
     87,   88,    1,   90,   64,  104,    1,  104,  104,   69,
     70,    1,   72,  104,   74,  104,    1,    2,  104,   79,
    104,  104,   21,   83,  104,  104,   86,   87,   88,   24,
     90,   26,  104,  104,  104,  104,  104,  104,   33,   38,
     39,   40,  104,   38,   39,   40,  104,  104,   38,   39,
     40,   36,  104,   38,   39,   40,   55,   56,   57,  104,
     55,   56,   57,   48,    2,   55,   56,   57,  104,   59,
     55,   56,   57,    2,   12,   13,  104,   15,  104,   17,
     18,  104,    2,   12,   13,  104,  104,  104,   17,   18,
    104,  104,   12,   13,   11,   15,  104,   17,   18,    1,
    104,  104,  104,  104,   21,  104,   23,  104,   46,   26,
     48,  104,   50,  104,   52,  104,   33,   46,   35,   48,
     37,   50,  104,   52,   53,    1,   46,  104,   48,   46,
     50,  104,   52,  104,  104,   11,   38,   39,   40,   61,
     62,   63,   64,   65,   66,  104,  104,   69,  104,  104,
     26,   53,  104,   55,   56,   57,  104,   33,  104,  104,
     64,  104,   38,   39,   40,   69,   70,  104,   72,  104,
     74,  104,  104,  104,  104,   79,  104,  104,  104,   55,
     56,   57,   86,   87,   88,  104,   90,  104,  104,   64,
    104,  104,    2,  104,   69,   70,  104,   72,  104,   74,
    104,  104,   12,   13,   79,  104,  104,   17,   18,  104,
    104,   86,   87,   88,  104,   90,  104,  104,  104,  104,
    104,  104,   64,  104,  104,  104,  104,   69,   70,    1,
     72,  104,   74,  104,  104,  104,   46,   79,   48,  104,
     50,  104,   52,  104,   86,   87,   88,   64,   90,    2,
      1,  104,   69,   70,   26,   72,  104,   74,  104,   12,
     13,   33,   79,    1,   17,   18,   38,   39,   40,   86,
     87,   88,  104,   90,  104,  104,   27,  104,  104,  104,
    104,  104,  104,   55,   56,   57,  104,   38,   39,   40,
    104,  104,  104,   46,  104,   48,  104,   50,  104,   52,
     38,   39,   40,  104,   55,   56,   57,  104,  104,  104,
     71,  104,  104,  104,   75,  104,  104,   55,   56,   57,
     81,  104,  104,   84,   85,  104,  104,  104,  104,  104,
    104,  104,  104,  104,  104,  104,  104,   98,
);
    const YY_SHIFT_USE_DFLT = -13;
    const YY_SHIFT_MAX = 236;
    static public $yy_shift_ofst = array(
    517,  317,  129,  129,  364,  364,  317,  129,   35,   35,
    -12,  129,  129,  176,  129,  129,  129,  129,  129,  129,
    129,  129,  129,   82,  129,  270,  129,  223,  129,  129,
    129,  129,  129,  129,   82,  129,  129,  411,  411,  458,
    458,  458,  458,  458, 1754, 1635, 1858, 1858, 1858, 1858,
   1858,  517,  459, 1007, 1640, 1525, 1442, 1728, 1359, 1110,
   1276, 1631, 1879,  525, 1193, 1892, 1892, 1892, 1892, 1892,
   1892, 1892, 1892, 1892, 1892,  760, 1892, 1892,  572,  572,
    820,  847,  299,  103,  986,   -3,  667,  803,  803,   92,
    103,  299,  299,  103,  478,   50,  144,  634,   10,  636,
    543,  614,  232,  243,  232,  255,  149,   36,  401,  419,
    398,  245,   36,  420,  431,  405,  484,  245,  343,  267,
    343,  267,  343,  343,  343,  343,  343,  343,  -13, 1692,
   1701, 1710, 1877, 1820,  584,  970,  794,  515,  107,  184,
    245,  184,  245,   63,   63,   63,   64,  184,  245,   63,
     63,   63,   63,   63,  154,  245,  245,  154,  245,  245,
    245,  245,  245,  245,  245,  245,  245,  245,  245,  245,
    245,  290,  170,  245,  343,  343,  343,  573,  343,  573,
    498,  426,  267,  267,  343,  267,  -13,  -13,  -13,  -13,
    -13, 1645, 1713,  843,  502,   84,  -10,  238,   22,   -5,
    104,  212,  134,  259,  304,  333,  273,   99,  244,  210,
    311,  466,  438,  470,  479,  461,  483,  475,  495,  469,
    500,  516,  521,  522,  498,  530,  549,  518,  533,  417,
    553,  476,   -2,  187,  258,  427,  289,
);
    const YY_REDUCE_USE_DFLT = -70;
    const YY_REDUCE_MAX = 190;
    static public $yy_reduce_ofst = array(
   1708,  471,  534,  569,  599,  632,  504,  657,  852,  798,
    740,  989, 1045, 1348, 1487, 1404, 1321, 1072, 1238, 1155,
   1128,  686,  823, 1099, 1294, 1182, 1265, 1514, 1377, 1431,
   1460, 1211,  906,  715,  769, 1016,  881, 1543, 1570, 1813,
    961, 1788, 1755, 1726,  971,  682,  653, 1869, 1041, 1012,
    971,   -7,   18,   21,  -69,  -69,  -69,  -69,  -69,  -69,
    -69,  -69,  -69,  -69,  -69,  -69,  -69,  -69,  -69,  -69,
    -69,  -69,  -69,  -69,  -69,   81,  -69,  -69,  -69,  -69,
    175,  112,  128,  137,  254,  301,  160,  274,  217,   11,
    264,  316,  222,   -6,  119,  358,  358,  252,  252,  338,
    297,  252,  261,  279,  297,  334,  279,  269,  279,  369,
    347,  370,  296,  367,  252,  252,  252,  320,  252,  310,
    252,  279,  384,  252,  252,  252,  252,  252,  252,   60,
     60,   60,   60,   60,   60,  510,  506,   60,   60,  535,
    503,  539,  503,  487,  487,  487,  497,  472,  503,  487,
    487,  487,  487,  487,  494,  503,  503,  509,  503,  503,
    503,  503,  503,  503,  503,  503,  503,  503,  503,  503,
    503,  531,  540,  503,  209,  209,  209,  400,  209,  400,
    373,  303,  181,  181,  209,  181,  138,   32,  -52,  386,
    390,
);
    static public $yyExpectedTokens = array(
         array(3, 4, 5, 6, 7, 8, 12, 13, 16, 19, 20, 25, 29, 31, 32, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 30, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 30, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 53, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 52, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 54, 58, ),
         array(12, 13, 14, 16, 17, 19, 20, 25, 29, 31, 32, 34, 36, 39, 43, 44, 45, 46, 47, 49, 51, 54, 58, ),
         array(1, 11, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 24, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(1, 26, 33, 38, 39, 40, 55, 56, 57, ),
         array(3, 4, 5, 6, 7, 8, 12, 13, 16, 19, 20, 25, 29, 31, 32, ),
         array(14, 17, 49, 51, 54, ),
         array(5, 12, 13, 14, 16, 19, 20, 25, 29, 31, 32, 58, 59, ),
         array(1, 38, 39, 40, 55, 56, 57, 59, ),
         array(1, 37, 38, 39, 40, 55, 56, 57, ),
         array(1, 11, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 53, 55, 56, 57, ),
         array(1, 2, 38, 39, 40, 55, 56, 57, ),
         array(1, 11, 38, 39, 40, 55, 56, 57, ),
         array(1, 11, 38, 39, 40, 55, 56, 57, ),
         array(1, 21, 38, 39, 40, 55, 56, 57, ),
         array(1, 27, 38, 39, 40, 55, 56, 57, ),
         array(1, 37, 38, 39, 40, 55, 56, 57, ),
         array(1, 11, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 11, 18, 26, 33, 36, 48, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(1, 38, 39, 40, 55, 56, 57, ),
         array(38, 39, 40, 55, 56, 57, ),
         array(38, 39, 40, 55, 56, 57, ),
         array(1, 11, 26, 33, ),
         array(14, 17, 51, 54, ),
         array(1, 26, 33, ),
         array(14, 36, 54, ),
         array(5, 12, 13, 14, 16, 19, 20, 25, 29, 31, 32, 58, 59, ),
         array(12, 13, 17, 26, 28, 33, ),
         array(12, 13, 17, 26, 28, 33, ),
         array(12, 13, 17, 26, 33, ),
         array(12, 13, 17, 26, 33, ),
         array(18, 46, 52, ),
         array(14, 36, 54, ),
         array(1, 26, 33, ),
         array(1, 26, 33, ),
         array(14, 36, 54, ),
         array(1, 2, ),
         array(11, 22, 26, 33, 41, ),
         array(11, 22, 26, 33, 41, ),
         array(1, 11, 26, 27, 33, ),
         array(1, 11, 26, 33, ),
         array(13, 14, 17, 54, ),
         array(12, 13, 17, 50, ),
         array(1, 11, 26, 33, ),
         array(12, 13, 17, ),
         array(15, 18, 48, ),
         array(12, 13, 17, ),
         array(8, 9, 10, ),
         array(15, 18, 48, ),
         array(14, 17, ),
         array(18, 48, ),
         array(1, 18, ),
         array(14, 54, ),
         array(26, 33, ),
         array(14, 17, ),
         array(26, 33, ),
         array(1, 53, ),
         array(1, 28, ),
         array(1, 11, ),
         array(26, 33, ),
         array(1, ),
         array(18, ),
         array(1, ),
         array(18, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(),
         array(2, 12, 13, 15, 17, 18, 46, 48, 50, 52, ),
         array(2, 12, 13, 17, 18, 46, 48, 50, 52, 53, ),
         array(2, 12, 13, 15, 17, 18, 46, 48, 50, 52, ),
         array(2, 12, 13, 17, 18, 46, 48, 50, 52, ),
         array(2, 12, 13, 17, 18, 46, 48, 50, 52, ),
         array(12, 13, 17, 18, 46, 48, 50, 52, ),
         array(13, 14, 17, 34, 54, ),
         array(12, 13, 17, 50, ),
         array(12, 13, 17, ),
         array(15, 46, 52, ),
         array(14, 54, ),
         array(26, 33, ),
         array(14, 54, ),
         array(26, 33, ),
         array(46, 52, ),
         array(46, 52, ),
         array(46, 52, ),
         array(13, 36, ),
         array(14, 54, ),
         array(26, 33, ),
         array(46, 52, ),
         array(46, 52, ),
         array(46, 52, ),
         array(46, 52, ),
         array(46, 52, ),
         array(46, 52, ),
         array(26, 33, ),
         array(26, 33, ),
         array(46, 52, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(26, 33, ),
         array(15, 22, ),
         array(14, 54, ),
         array(26, 33, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(2, ),
         array(1, ),
         array(2, ),
         array(36, ),
         array(9, ),
         array(18, ),
         array(18, ),
         array(1, ),
         array(18, ),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(1, 2, 36, 38, 39, 40, 48, 55, 56, 57, ),
         array(11, 21, 23, 26, 33, 35, 37, 46, ),
         array(11, 15, 26, 33, 36, 48, ),
         array(12, 13, 17, 50, ),
         array(36, 46, 48, 53, ),
         array(28, 36, 48, ),
         array(22, 41, 59, ),
         array(22, 41, 53, ),
         array(17, 50, ),
         array(15, 46, ),
         array(21, 35, ),
         array(35, 37, ),
         array(35, 37, ),
         array(35, 37, ),
         array(46, 53, ),
         array(35, 53, ),
         array(36, 48, ),
         array(36, 48, ),
         array(22, 41, ),
         array(36, 48, ),
         array(22, ),
         array(53, ),
         array(23, ),
         array(17, ),
         array(37, ),
         array(17, ),
         array(36, ),
         array(11, ),
         array(17, ),
         array(17, ),
         array(15, ),
         array(17, ),
         array(17, ),
         array(36, ),
         array(17, ),
         array(17, ),
         array(51, ),
         array(34, ),
         array(51, ),
         array(17, ),
         array(42, ),
         array(5, ),
         array(17, ),
         array(53, ),
         array(34, ),
         array(46, ),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
);
    static public $yy_default = array(
    335,  510,  490,  490,  525,  525,  525,  490,  525,  525,
    525,  525,  525,  525,  525,  525,  525,  525,  525,  525,
    525,  525,  525,  525,  525,  525,  525,  525,  525,  525,
    525,  525,  525,  525,  525,  525,  525,  525,  525,  525,
    525,  525,  525,  525,  525,  393,  369,  393,  360,  393,
    357,  332,  525,  525,  525,  525,  525,  525,  525,  525,
    525,  525,  398,  525,  525,  395,  511,  414,  405,  489,
    512,  404,  513,  398,  400,  432,  374,  488,  421,  420,
    407,  525,  393,  525,  525,  393,  393,  393,  393,  502,
    525,  393,  393,  525,  383,  422,  422,  407,  407,  525,
    455,  407,  455,  445,  455,  525,  445,  525,  445,  387,
    525,  371,  525,  393,  407,  407,  407,  393,  417,  499,
    407,  445,  389,  423,  424,  425,  410,  411,  497,  444,
    444,  444,  444,  444,  444,  525,  457,  455,  471,  525,
    379,  525,  380,  481,  452,  449,  455,  525,  364,  480,
    482,  453,  451,  483,  448,  378,  356,  450,  373,  366,
    372,  377,  362,  376,  367,  354,  370,  361,  368,  358,
    382,  525,  525,  381,  390,  439,  384,  491,  388,  492,
    455,  348,  503,  500,  413,  477,  455,  496,  496,  496,
    455,  432,  428,  432,  456,  432,  432,  422,  422,  525,
    428,  525,  525,  525,  525,  428,  525,  525,  440,  422,
    432,  422,  525,  401,  525,  525,  525,  501,  525,  525,
    525,  525,  525,  525,  471,  525,  525,  525,  525,  525,
    525,  434,  340,  525,  435,  430,  428,  394,  363,  505,
    506,  412,  436,  418,  476,  392,  479,  437,  443,  442,
    419,  471,  352,  375,  345,  336,  337,  338,  339,  342,
    341,  343,  344,  438,  416,  468,  504,  346,  347,  406,
    349,  350,  351,  415,  466,  402,  469,  391,  498,  458,
    434,  520,  386,  508,  509,  507,  431,  441,  522,  517,
    524,  523,  518,  521,  429,  519,  493,  494,  516,  515,
    514,  385,  427,  426,  495,  487,  435,  462,  461,  486,
    485,  460,  459,  478,  334,  470,  464,  463,  465,  433,
    467,  484,  446,  447,  473,  474,  475,  472,  454,  409,
    408,  333,
);
    const YYNOCODE = 105;
    const YYSTACKDEPTH = 500;
    const YYNSTATE = 332;
    const YYNRULE = 193;
    const YYERRORSYMBOL = 60;
    const YYERRSYMDT = 'yy0';
    const YYFALLBACK = 0;
    public static $yyFallback = array(
    );
    public function Trace($TraceFILE, $zTracePrompt)
    {
        if (!$TraceFILE) {
            $zTracePrompt = 0;
        } elseif (!$zTracePrompt) {
            $TraceFILE = 0;
        }
        $this->yyTraceFILE = $TraceFILE;
        $this->yyTracePrompt = $zTracePrompt;
    }

    public function PrintTrace()
    {
        $this->yyTraceFILE = fopen('php://output', 'w');
        $this->yyTracePrompt = '<br>';
    }

    public $yyTraceFILE;
    public $yyTracePrompt;
    public $yyidx;                    /* Index of top element in stack */
    public $yyerrcnt;                 /* Shifts left before out of the error */
    public $yystack = array();  /* The parser's stack */

    public $yyTokenName = array(
  '$',             'VERT',          'COLON',         'PHP',         
  'NOCACHE',       'TEXT',          'STRIPON',       'STRIPOFF',    
  'LITERALSTART',  'LITERALEND',    'LITERAL',       'RDEL',        
  'SIMPELOUTPUT',  'LDEL',          'DOLLARID',      'EQUAL',       
  'SIMPLETAG',     'ID',            'PTR',           'LDELIF',      
  'LDELFOR',       'SEMICOLON',     'INCDEC',        'TO',          
  'STEP',          'LDELFOREACH',   'SPACE',         'AS',          
  'APTR',          'LDELSETFILTER',  'SMARTYBLOCKCHILDPARENT',  'CLOSETAG',    
  'LDELSLASH',     'ATTR',          'INTEGER',       'COMMA',       
  'OPENP',         'CLOSEP',        'MATH',          'UNIMATH',     
  'ISIN',          'INSTANCEOF',    'QMARK',         'NOT',         
  'TYPECAST',      'HEX',           'DOT',           'SINGLEQUOTESTRING',
  'DOUBLECOLON',   'NAMESPACE',     'AT',            'HATCH',       
  'OPENB',         'CLOSEB',        'DOLLAR',        'LOGOP',       
  'TLOGOP',        'SINGLECOND',    'QUOTE',         'BACKTICK',    
  'error',         'start',         'template',      'template_element',
  'smartytag',     'literal',       'text_content',  'literal_elements',
  'literal_element',  'tag',           'variable',      'attributes',  
  'value',         'expr',          'varindexed',    'modifierlist',
  'statement',     'statements',    'foraction',     'varvar',      
  'modparameters',  'attribute',     'ternary',       'array',       
  'lop',           'scond',         'ns1',           'function',    
  'doublequoted_with_quotes',  'static_class_access',  'object',        'arrayindex',  
  'indexdef',      'varvarele',     'objectchain',   'objectelement',
  'method',        'params',        'modifier',      'modparameter',
  'arrayelements',  'arrayelement',  'doublequoted',  'doublequotedcontent',
    );

    public static $yyRuleName = array(
  'start ::= template',
  'template ::= template_element',
  'template ::= template template_element',
  'template ::=',
  'template_element ::= smartytag',
  'template_element ::= literal',
  'template_element ::= PHP',
  'template_element ::= NOCACHE',
  'template_element ::= text_content',
  'text_content ::= TEXT',
  'text_content ::= text_content TEXT',
  'template_element ::= STRIPON',
  'template_element ::= STRIPOFF',
  'literal ::= LITERALSTART LITERALEND',
  'literal ::= LITERALSTART literal_elements LITERALEND',
  'literal_elements ::= literal_elements literal_element',
  'literal_elements ::=',
  'literal_element ::= literal',
  'literal_element ::= LITERAL',
  'smartytag ::= tag RDEL',
  'smartytag ::= SIMPELOUTPUT',
  'tag ::= LDEL variable',
  'tag ::= LDEL variable attributes',
  'tag ::= LDEL value',
  'tag ::= LDEL value attributes',
  'tag ::= LDEL expr',
  'tag ::= LDEL expr attributes',
  'tag ::= LDEL DOLLARID EQUAL value',
  'tag ::= LDEL DOLLARID EQUAL expr',
  'tag ::= LDEL DOLLARID EQUAL expr attributes',
  'tag ::= LDEL varindexed EQUAL expr attributes',
  'smartytag ::= SIMPLETAG',
  'tag ::= LDEL ID attributes',
  'tag ::= LDEL ID',
  'tag ::= LDEL ID modifierlist attributes',
  'tag ::= LDEL ID PTR ID attributes',
  'tag ::= LDEL ID PTR ID modifierlist attributes',
  'tag ::= LDELIF expr',
  'tag ::= LDELIF expr attributes',
  'tag ::= LDELIF statement',
  'tag ::= LDELIF statement attributes',
  'tag ::= LDELFOR statements SEMICOLON expr SEMICOLON varindexed foraction attributes',
  'foraction ::= EQUAL expr',
  'foraction ::= INCDEC',
  'tag ::= LDELFOR statement TO expr attributes',
  'tag ::= LDELFOR statement TO expr STEP expr attributes',
  'tag ::= LDELFOREACH attributes',
  'tag ::= LDELFOREACH SPACE value AS varvar attributes',
  'tag ::= LDELFOREACH SPACE value AS varvar APTR varvar attributes',
  'tag ::= LDELFOREACH SPACE expr AS varvar attributes',
  'tag ::= LDELFOREACH SPACE expr AS varvar APTR varvar attributes',
  'tag ::= LDELSETFILTER ID modparameters',
  'tag ::= LDELSETFILTER ID modparameters modifierlist',
  'tag ::= LDEL SMARTYBLOCKCHILDPARENT',
  'smartytag ::= CLOSETAG',
  'tag ::= LDELSLASH ID',
  'tag ::= LDELSLASH ID modifierlist',
  'tag ::= LDELSLASH ID PTR ID',
  'tag ::= LDELSLASH ID PTR ID modifierlist',
  'attributes ::= attributes attribute',
  'attributes ::= attribute',
  'attributes ::=',
  'attribute ::= SPACE ID EQUAL ID',
  'attribute ::= ATTR expr',
  'attribute ::= ATTR value',
  'attribute ::= SPACE ID',
  'attribute ::= SPACE expr',
  'attribute ::= SPACE value',
  'attribute ::= SPACE INTEGER EQUAL expr',
  'statements ::= statement',
  'statements ::= statements COMMA statement',
  'statement ::= DOLLARID EQUAL INTEGER',
  'statement ::= DOLLARID EQUAL expr',
  'statement ::= varindexed EQUAL expr',
  'statement ::= OPENP statement CLOSEP',
  'expr ::= value',
  'expr ::= ternary',
  'expr ::= DOLLARID COLON ID',
  'expr ::= expr MATH value',
  'expr ::= expr UNIMATH value',
  'expr ::= array',
  'expr ::= expr modifierlist',
  'expr ::= expr lop expr',
  'expr ::= expr scond',
  'expr ::= expr ISIN array',
  'expr ::= expr ISIN value',
  'expr ::= variable INSTANCEOF ns1',
  'expr ::= variable INSTANCEOF variable',
  'ternary ::= OPENP expr CLOSEP QMARK DOLLARID COLON expr',
  'ternary ::= OPENP expr CLOSEP QMARK expr COLON expr',
  'value ::= variable',
  'value ::= UNIMATH value',
  'value ::= NOT value',
  'value ::= TYPECAST value',
  'value ::= variable INCDEC',
  'value ::= HEX',
  'value ::= INTEGER',
  'value ::= INTEGER DOT INTEGER',
  'value ::= INTEGER DOT',
  'value ::= DOT INTEGER',
  'value ::= ID',
  'value ::= function',
  'value ::= OPENP expr CLOSEP',
  'value ::= SINGLEQUOTESTRING',
  'value ::= doublequoted_with_quotes',
  'value ::= varindexed DOUBLECOLON static_class_access',
  'value ::= smartytag',
  'value ::= value modifierlist',
  'value ::= NAMESPACE',
  'value ::= ns1 DOUBLECOLON static_class_access',
  'ns1 ::= ID',
  'ns1 ::= NAMESPACE',
  'variable ::= DOLLARID',
  'variable ::= varindexed',
  'variable ::= varvar AT ID',
  'variable ::= object',
  'variable ::= HATCH ID HATCH',
  'variable ::= HATCH ID HATCH arrayindex',
  'variable ::= HATCH variable HATCH',
  'variable ::= HATCH variable HATCH arrayindex',
  'varindexed ::= DOLLARID arrayindex',
  'varindexed ::= varvar arrayindex',
  'arrayindex ::= arrayindex indexdef',
  'arrayindex ::=',
  'indexdef ::= DOT DOLLARID',
  'indexdef ::= DOT varvar',
  'indexdef ::= DOT varvar AT ID',
  'indexdef ::= DOT ID',
  'indexdef ::= DOT INTEGER',
  'indexdef ::= DOT LDEL expr RDEL',
  'indexdef ::= OPENB ID CLOSEB',
  'indexdef ::= OPENB ID DOT ID CLOSEB',
  'indexdef ::= OPENB SINGLEQUOTESTRING CLOSEB',
  'indexdef ::= OPENB INTEGER CLOSEB',
  'indexdef ::= OPENB DOLLARID CLOSEB',
  'indexdef ::= OPENB variable CLOSEB',
  'indexdef ::= OPENB value CLOSEB',
  'indexdef ::= OPENB expr CLOSEB',
  'indexdef ::= OPENB CLOSEB',
  'varvar ::= DOLLARID',
  'varvar ::= DOLLAR',
  'varvar ::= varvar varvarele',
  'varvarele ::= ID',
  'varvarele ::= SIMPELOUTPUT',
  'varvarele ::= LDEL expr RDEL',
  'object ::= varindexed objectchain',
  'objectchain ::= objectelement',
  'objectchain ::= objectchain objectelement',
  'objectelement ::= PTR ID arrayindex',
  'objectelement ::= PTR varvar arrayindex',
  'objectelement ::= PTR LDEL expr RDEL arrayindex',
  'objectelement ::= PTR ID LDEL expr RDEL arrayindex',
  'objectelement ::= PTR method',
  'function ::= ns1 OPENP params CLOSEP',
  'method ::= ID OPENP params CLOSEP',
  'method ::= DOLLARID OPENP params CLOSEP',
  'params ::= params COMMA expr',
  'params ::= expr',
  'params ::=',
  'modifierlist ::= modifierlist modifier modparameters',
  'modifierlist ::= modifier modparameters',
  'modifier ::= VERT AT ID',
  'modifier ::= VERT ID',
  'modparameters ::= modparameters modparameter',
  'modparameters ::=',
  'modparameter ::= COLON value',
  'modparameter ::= COLON array',
  'static_class_access ::= method',
  'static_class_access ::= method objectchain',
  'static_class_access ::= ID',
  'static_class_access ::= DOLLARID arrayindex',
  'static_class_access ::= DOLLARID arrayindex objectchain',
  'lop ::= LOGOP',
  'lop ::= TLOGOP',
  'scond ::= SINGLECOND',
  'array ::= OPENB arrayelements CLOSEB',
  'arrayelements ::= arrayelement',
  'arrayelements ::= arrayelements COMMA arrayelement',
  'arrayelements ::=',
  'arrayelement ::= value APTR expr',
  'arrayelement ::= ID APTR expr',
  'arrayelement ::= expr',
  'doublequoted_with_quotes ::= QUOTE QUOTE',
  'doublequoted_with_quotes ::= QUOTE doublequoted QUOTE',
  'doublequoted ::= doublequoted doublequotedcontent',
  'doublequoted ::= doublequotedcontent',
  'doublequotedcontent ::= BACKTICK variable BACKTICK',
  'doublequotedcontent ::= BACKTICK expr BACKTICK',
  'doublequotedcontent ::= DOLLARID',
  'doublequotedcontent ::= LDEL variable RDEL',
  'doublequotedcontent ::= LDEL expr RDEL',
  'doublequotedcontent ::= smartytag',
  'doublequotedcontent ::= TEXT',
    );

    public function tokenName($tokenType)
    {
        if ($tokenType === 0) {
            return 'End of Input';
        }
        if ($tokenType > 0 && $tokenType < count($this->yyTokenName)) {
            return $this->yyTokenName[$tokenType];
        } else {
            return "Unknown";
        }
    }

    public static function yy_destructor($yymajor, $yypminor)
    {
        switch ($yymajor) {
            default:  break;   /* If no destructor action specified: do nothing */
        }
    }

    public function yy_pop_parser_stack()
    {
        if (empty($this->yystack)) {
            return;
        }
        $yytos = array_pop($this->yystack);
        if ($this->yyTraceFILE && $this->yyidx >= 0) {
            fwrite($this->yyTraceFILE,
                $this->yyTracePrompt . 'Popping ' . $this->yyTokenName[$yytos->major] .
                    "\n");
        }
        $yymajor = $yytos->major;
        self::yy_destructor($yymajor, $yytos->minor);
        $this->yyidx--;

        return $yymajor;
    }

    public function __destruct()
    {
        while ($this->yystack !== Array()) {
            $this->yy_pop_parser_stack();
        }
        if (is_resource($this->yyTraceFILE)) {
            fclose($this->yyTraceFILE);
        }
    }

    public function yy_get_expected_tokens($token)
    {
        static $res3 = array();
        static $res4 = array();
        $state = $this->yystack[$this->yyidx]->stateno;
        $expected = self::$yyExpectedTokens[$state];
        if (isset($res3[$state][$token])) {
            if ($res3[$state][$token]) {
                return $expected;
            }
        } else {
            if ($res3[$state][$token] = in_array($token, self::$yyExpectedTokens[$state], true)) {
                return $expected;
            }
        }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ == 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return array_unique($expected);
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno][1];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno][0]);
                    if (isset(self::$yyExpectedTokens[$nextstate])) {
                $expected = array_merge($expected, self::$yyExpectedTokens[$nextstate]);
                        if (isset($res4[$nextstate][$token])) {
                            if ($res4[$nextstate][$token]) {
                                $this->yyidx = $yyidx;
                                $this->yystack = $stack;
                                return array_unique($expected);
                            }
                        } else {
                            if ($res4[$nextstate][$token] = in_array($token, self::$yyExpectedTokens[$nextstate], true)) {
                                $this->yyidx = $yyidx;
                                $this->yystack = $stack;
                                return array_unique($expected);
                            }
                        }
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = new TP_yyStackEntry;
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno][0];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate == self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return array_unique($expected);
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return $expected;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
    $this->yyidx = $yyidx;
    $this->yystack = $stack;

        return array_unique($expected);
    }

    public function yy_is_expected_token($token)
    {
        static $res = array();
        static $res2 = array();
        if ($token === 0) {
            return true; // 0 is not part of this
        }
        $state = $this->yystack[$this->yyidx]->stateno;
        if (isset($res[$state][$token])) {
            if ($res[$state][$token]) {
                return true;
            }
        } else {
            if ($res[$state][$token] = in_array($token, self::$yyExpectedTokens[$state], true)) {
                return true;
            }
       }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ == 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return true;
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno][1];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno][0]);
                    if (isset($res2[$nextstate][$token])) {
                        if ($res2[$nextstate][$token]) {
                            $this->yyidx = $yyidx;
                            $this->yystack = $stack;
                            return true;
                        }
                    } else {
                        if ($res2[$nextstate][$token] = (isset(self::$yyExpectedTokens[$nextstate]) && in_array($token, self::$yyExpectedTokens[$nextstate], true))) {
                            $this->yyidx = $yyidx;
                            $this->yystack = $stack;
                            return true;
                        }
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = new TP_yyStackEntry;
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno][0];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate == self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        if (!$token) {
                            // end of input: this is valid
                            return true;
                        }
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return false;
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return true;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
        $this->yyidx = $yyidx;
        $this->yystack = $stack;

        return true;
    }

   public function yy_find_shift_action($iLookAhead)
    {
        $stateno = $this->yystack[$this->yyidx]->stateno;

        /* if ($this->yyidx < 0) return self::YY_NO_ACTION;  */
        if (!isset(self::$yy_shift_ofst[$stateno])) {
            // no shift actions
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_shift_ofst[$stateno];
        if ($i === self::YY_SHIFT_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead == self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            if (count(self::$yyFallback) && $iLookAhead < count(self::$yyFallback)
                   && ($iFallback = self::$yyFallback[$iLookAhead]) != 0) {
                if ($this->yyTraceFILE) {
                    fwrite($this->yyTraceFILE, $this->yyTracePrompt . "FALLBACK " .
                        $this->yyTokenName[$iLookAhead] . " => " .
                        $this->yyTokenName[$iFallback] . "\n");
                }

                return $this->yy_find_shift_action($iFallback);
            }

            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    public function yy_find_reduce_action($stateno, $iLookAhead)
    {
        /* $stateno = $this->yystack[$this->yyidx]->stateno; */

        if (!isset(self::$yy_reduce_ofst[$stateno])) {
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_reduce_ofst[$stateno];
        if ($i == self::YY_REDUCE_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead == self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    public function yy_shift($yyNewState, $yyMajor, $yypMinor)
    {
        $this->yyidx++;
        if ($this->yyidx >= self::YYSTACKDEPTH) {
            $this->yyidx--;
            if ($this->yyTraceFILE) {
                fprintf($this->yyTraceFILE, "%sStack Overflow!\n", $this->yyTracePrompt);
            }
            while ($this->yyidx >= 0) {
                $this->yy_pop_parser_stack();
            }
#line 214 "./lexer/smarty_internal_templateparser.y"

    $this->internalError = true;
    $this->compiler->trigger_template_error("Stack overflow in template parser");

            return;
        }
        $yytos = new TP_yyStackEntry;
        $yytos->stateno = $yyNewState;
        $yytos->major = $yyMajor;
        $yytos->minor = $yypMinor;
        $this->yystack[] = $yytos;
        if ($this->yyTraceFILE && $this->yyidx > 0) {
            fprintf($this->yyTraceFILE, "%sShift %d\n", $this->yyTracePrompt,
                $yyNewState);
            fprintf($this->yyTraceFILE, "%sStack:", $this->yyTracePrompt);
            for ($i = 1; $i <= $this->yyidx; $i++) {
                fprintf($this->yyTraceFILE, " %s",
                    $this->yyTokenName[$this->yystack[$i]->major]);
            }
            fwrite($this->yyTraceFILE,"\n");
        }
    }

    public static $yyRuleInfo = array(
  array( 0 => 61, 1 => 1 ),
  array( 0 => 62, 1 => 1 ),
  array( 0 => 62, 1 => 2 ),
  array( 0 => 62, 1 => 0 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 66, 1 => 1 ),
  array( 0 => 66, 1 => 2 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 65, 1 => 2 ),
  array( 0 => 65, 1 => 3 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 0 ),
  array( 0 => 68, 1 => 1 ),
  array( 0 => 68, 1 => 1 ),
  array( 0 => 64, 1 => 2 ),
  array( 0 => 64, 1 => 1 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 4 ),
  array( 0 => 69, 1 => 4 ),
  array( 0 => 69, 1 => 5 ),
  array( 0 => 69, 1 => 5 ),
  array( 0 => 64, 1 => 1 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 4 ),
  array( 0 => 69, 1 => 5 ),
  array( 0 => 69, 1 => 6 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 8 ),
  array( 0 => 78, 1 => 2 ),
  array( 0 => 78, 1 => 1 ),
  array( 0 => 69, 1 => 5 ),
  array( 0 => 69, 1 => 7 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 6 ),
  array( 0 => 69, 1 => 8 ),
  array( 0 => 69, 1 => 6 ),
  array( 0 => 69, 1 => 8 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 4 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 64, 1 => 1 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 69, 1 => 3 ),
  array( 0 => 69, 1 => 4 ),
  array( 0 => 69, 1 => 5 ),
  array( 0 => 71, 1 => 2 ),
  array( 0 => 71, 1 => 1 ),
  array( 0 => 71, 1 => 0 ),
  array( 0 => 81, 1 => 4 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 4 ),
  array( 0 => 77, 1 => 1 ),
  array( 0 => 77, 1 => 3 ),
  array( 0 => 76, 1 => 3 ),
  array( 0 => 76, 1 => 3 ),
  array( 0 => 76, 1 => 3 ),
  array( 0 => 76, 1 => 3 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 2 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 2 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 82, 1 => 7 ),
  array( 0 => 82, 1 => 7 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 3 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 3 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 3 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 3 ),
  array( 0 => 86, 1 => 1 ),
  array( 0 => 86, 1 => 1 ),
  array( 0 => 70, 1 => 1 ),
  array( 0 => 70, 1 => 1 ),
  array( 0 => 70, 1 => 3 ),
  array( 0 => 70, 1 => 1 ),
  array( 0 => 70, 1 => 3 ),
  array( 0 => 70, 1 => 4 ),
  array( 0 => 70, 1 => 3 ),
  array( 0 => 70, 1 => 4 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 91, 1 => 2 ),
  array( 0 => 91, 1 => 0 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 4 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 4 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 5 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 79, 1 => 1 ),
  array( 0 => 79, 1 => 1 ),
  array( 0 => 79, 1 => 2 ),
  array( 0 => 93, 1 => 1 ),
  array( 0 => 93, 1 => 1 ),
  array( 0 => 93, 1 => 3 ),
  array( 0 => 90, 1 => 2 ),
  array( 0 => 94, 1 => 1 ),
  array( 0 => 94, 1 => 2 ),
  array( 0 => 95, 1 => 3 ),
  array( 0 => 95, 1 => 3 ),
  array( 0 => 95, 1 => 5 ),
  array( 0 => 95, 1 => 6 ),
  array( 0 => 95, 1 => 2 ),
  array( 0 => 87, 1 => 4 ),
  array( 0 => 96, 1 => 4 ),
  array( 0 => 96, 1 => 4 ),
  array( 0 => 97, 1 => 3 ),
  array( 0 => 97, 1 => 1 ),
  array( 0 => 97, 1 => 0 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 2 ),
  array( 0 => 98, 1 => 3 ),
  array( 0 => 98, 1 => 2 ),
  array( 0 => 80, 1 => 2 ),
  array( 0 => 80, 1 => 0 ),
  array( 0 => 99, 1 => 2 ),
  array( 0 => 99, 1 => 2 ),
  array( 0 => 89, 1 => 1 ),
  array( 0 => 89, 1 => 2 ),
  array( 0 => 89, 1 => 1 ),
  array( 0 => 89, 1 => 2 ),
  array( 0 => 89, 1 => 3 ),
  array( 0 => 84, 1 => 1 ),
  array( 0 => 84, 1 => 1 ),
  array( 0 => 85, 1 => 1 ),
  array( 0 => 83, 1 => 3 ),
  array( 0 => 100, 1 => 1 ),
  array( 0 => 100, 1 => 3 ),
  array( 0 => 100, 1 => 0 ),
  array( 0 => 101, 1 => 3 ),
  array( 0 => 101, 1 => 3 ),
  array( 0 => 101, 1 => 1 ),
  array( 0 => 88, 1 => 2 ),
  array( 0 => 88, 1 => 3 ),
  array( 0 => 102, 1 => 2 ),
  array( 0 => 102, 1 => 1 ),
  array( 0 => 103, 1 => 3 ),
  array( 0 => 103, 1 => 3 ),
  array( 0 => 103, 1 => 1 ),
  array( 0 => 103, 1 => 3 ),
  array( 0 => 103, 1 => 3 ),
  array( 0 => 103, 1 => 1 ),
  array( 0 => 103, 1 => 1 ),
    );

    public static $yyReduceMap = array(
        0 => 0,
        1 => 1,
        2 => 2,
        4 => 4,
        5 => 5,
        6 => 6,
        7 => 7,
        8 => 8,
        9 => 9,
        17 => 9,
        18 => 9,
        43 => 9,
        66 => 9,
        67 => 9,
        75 => 9,
        76 => 9,
        80 => 9,
        90 => 9,
        95 => 9,
        96 => 9,
        101 => 9,
        103 => 9,
        104 => 9,
        108 => 9,
        110 => 9,
        115 => 9,
        176 => 9,
        181 => 9,
        10 => 10,
        11 => 11,
        12 => 12,
        13 => 13,
        16 => 13,
        14 => 14,
        74 => 14,
        15 => 15,
        91 => 15,
        93 => 15,
        94 => 15,
        122 => 15,
        19 => 19,
        20 => 20,
        21 => 21,
        23 => 21,
        25 => 21,
        22 => 22,
        24 => 22,
        26 => 22,
        27 => 27,
        28 => 27,
        29 => 29,
        30 => 30,
        31 => 31,
        32 => 32,
        33 => 33,
        34 => 34,
        35 => 35,
        36 => 36,
        37 => 37,
        38 => 38,
        40 => 38,
        39 => 39,
        41 => 41,
        42 => 42,
        44 => 44,
        45 => 45,
        46 => 46,
        47 => 47,
        49 => 47,
        48 => 48,
        50 => 48,
        51 => 51,
        52 => 52,
        53 => 53,
        54 => 54,
        55 => 55,
        56 => 56,
        57 => 57,
        58 => 58,
        59 => 59,
        60 => 60,
        69 => 60,
        157 => 60,
        161 => 60,
        165 => 60,
        166 => 60,
        61 => 61,
        158 => 61,
        164 => 61,
        62 => 62,
        63 => 63,
        64 => 63,
        65 => 65,
        142 => 65,
        68 => 68,
        70 => 70,
        71 => 71,
        72 => 71,
        73 => 73,
        77 => 77,
        78 => 78,
        79 => 78,
        81 => 81,
        107 => 81,
        82 => 82,
        83 => 83,
        84 => 84,
        85 => 85,
        86 => 86,
        87 => 86,
        88 => 88,
        89 => 89,
        92 => 92,
        97 => 97,
        98 => 98,
        99 => 99,
        100 => 100,
        102 => 102,
        105 => 105,
        106 => 106,
        109 => 109,
        111 => 111,
        112 => 112,
        113 => 113,
        114 => 114,
        116 => 116,
        117 => 117,
        118 => 118,
        119 => 119,
        120 => 120,
        121 => 121,
        123 => 123,
        178 => 123,
        124 => 124,
        125 => 125,
        126 => 126,
        127 => 127,
        128 => 128,
        129 => 129,
        137 => 129,
        130 => 130,
        131 => 131,
        132 => 132,
        133 => 132,
        135 => 132,
        136 => 132,
        134 => 134,
        138 => 138,
        139 => 139,
        140 => 140,
        182 => 140,
        141 => 141,
        143 => 143,
        144 => 144,
        145 => 145,
        146 => 146,
        147 => 147,
        148 => 148,
        149 => 149,
        150 => 150,
        151 => 151,
        152 => 152,
        153 => 153,
        154 => 154,
        155 => 155,
        156 => 156,
        159 => 159,
        160 => 160,
        162 => 162,
        163 => 163,
        167 => 167,
        168 => 168,
        169 => 169,
        170 => 170,
        171 => 171,
        172 => 172,
        173 => 173,
        174 => 174,
        175 => 175,
        177 => 177,
        179 => 179,
        180 => 180,
        183 => 183,
        184 => 184,
        185 => 185,
        186 => 186,
        187 => 186,
        189 => 186,
        188 => 188,
        190 => 190,
        191 => 191,
        192 => 192,
    );
#line 225 "./lexer/smarty_internal_templateparser.y"
    function yy_r0(){
    $this->root_buffer->prepend_array($this, $this->template_prefix);
    $this->root_buffer->append_array($this, $this->template_postfix);
    $this->_retvalue = $this->root_buffer->to_smarty_php($this);
    }
#line 235 "./lexer/smarty_internal_templateparser.y"
    function yy_r1(){
    if ($this->yystack[$this->yyidx + 0]->minor != null) {
        $this->current_buffer->append_subtree($this, $this->yystack[$this->yyidx + 0]->minor);
    }
    }
#line 242 "./lexer/smarty_internal_templateparser.y"
    function yy_r2(){
    if ($this->yystack[$this->yyidx + 0]->minor != null) {
        // because of possible code injection
        $this->current_buffer->append_subtree($this, $this->yystack[$this->yyidx + 0]->minor);
    }
    }
#line 256 "./lexer/smarty_internal_templateparser.y"
    function yy_r4(){
     if ($this->compiler->has_code) {
         $this->_retvalue = $this->mergePrefixCode($this->yystack[$this->yyidx + 0]->minor);
     } else {
         $this->_retvalue = null;
     }
    $this->compiler->has_variable_string = false;
    $this->block_nesting_level = count($this->compiler->_tag_stack);
    }
#line 267 "./lexer/smarty_internal_templateparser.y"
    function yy_r5(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Text($this->yystack[$this->yyidx + 0]->minor);
    }
#line 271 "./lexer/smarty_internal_templateparser.y"
    function yy_r6(){
    $code = $this->compiler->compileTag('private_php',array(array('code' => $this->yystack[$this->yyidx + 0]->minor), array('type' => $this->lex->phpType )),array());
    if ($this->compiler->has_code && !empty($code)) {
        $tmp =''; foreach ($this->compiler->prefix_code as $code) {$tmp.=$code;} $this->compiler->prefix_code=array();
        $this->_retvalue = new Smarty_Internal_ParseTree_Tag($this, $this->compiler->processNocacheCode($tmp.$code,true));
    } else {
        $this->_retvalue = null;
    }
    }
#line 282 "./lexer/smarty_internal_templateparser.y"
    function yy_r7(){
        $this->compiler->tag_nocache = true;
        $save = $this->template->compiled->has_nocache_code;
        $this->_retvalue = new Smarty_Internal_ParseTree_Tag($this, $this->compiler->processNocacheCode("<?php echo '{$this->yystack[$this->yyidx + 0]->minor}';?>\n", $this->compiler, true));
        $this->template->compiled->has_nocache_code = $save;
    }
#line 289 "./lexer/smarty_internal_templateparser.y"
    function yy_r8(){
        $this->_retvalue = $this->compiler->processText($this->yystack[$this->yyidx + 0]->minor);
    }
#line 293 "./lexer/smarty_internal_templateparser.y"
    function yy_r9(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
    }
#line 297 "./lexer/smarty_internal_templateparser.y"
    function yy_r10(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor . $this->yystack[$this->yyidx + 0]->minor;
    }
#line 302 "./lexer/smarty_internal_templateparser.y"
    function yy_r11(){
    $this->strip = true;
    }
#line 306 "./lexer/smarty_internal_templateparser.y"
    function yy_r12(){
    $this->strip = false;
    }
#line 311 "./lexer/smarty_internal_templateparser.y"
    function yy_r13(){
    $this->_retvalue = '';
    }
#line 315 "./lexer/smarty_internal_templateparser.y"
    function yy_r14(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    }
#line 319 "./lexer/smarty_internal_templateparser.y"
    function yy_r15(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 335 "./lexer/smarty_internal_templateparser.y"
    function yy_r19(){
    $this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor;
    }
#line 341 "./lexer/smarty_internal_templateparser.y"
    function yy_r20(){
    $var = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->lex->ldel_length, -$this->lex->rdel_length), ' $');
    if (preg_match('/^(.*)(\s+nocache)$/', $var, $match)) {
        $this->_retvalue = $this->compiler->compileTag('private_print_expression',array('nocache'),array('value'=>$this->compiler->compileVariable('\''.$match[1].'\'')));
    } else {
        $this->_retvalue = $this->compiler->compileTag('private_print_expression',array(),array('value'=>$this->compiler->compileVariable('\''.$var.'\'')));
    }
    }
#line 351 "./lexer/smarty_internal_templateparser.y"
    function yy_r21(){
    $this->_retvalue = $this->compiler->compileTag('private_print_expression',array(),array('value'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 355 "./lexer/smarty_internal_templateparser.y"
    function yy_r22(){
    $this->_retvalue = $this->compiler->compileTag('private_print_expression',$this->yystack[$this->yyidx + 0]->minor,array('value'=>$this->yystack[$this->yyidx + -1]->minor));
    }
#line 378 "./lexer/smarty_internal_templateparser.y"
    function yy_r27(){
    $this->_retvalue = $this->compiler->compileTag('assign',array(array('value'=>$this->yystack[$this->yyidx + 0]->minor),array('var'=>'\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'\'')));
    }
#line 386 "./lexer/smarty_internal_templateparser.y"
    function yy_r29(){
    $this->_retvalue = $this->compiler->compileTag('assign',array_merge(array(array('value'=>$this->yystack[$this->yyidx + -1]->minor),array('var'=>'\''.substr($this->yystack[$this->yyidx + -3]->minor,1).'\'')),$this->yystack[$this->yyidx + 0]->minor));
    }
#line 390 "./lexer/smarty_internal_templateparser.y"
    function yy_r30(){
    $this->_retvalue = $this->compiler->compileTag('assign',array_merge(array(array('value'=>$this->yystack[$this->yyidx + -1]->minor),array('var'=>$this->yystack[$this->yyidx + -3]->minor['var'])),$this->yystack[$this->yyidx + 0]->minor),array('smarty_internal_index'=>$this->yystack[$this->yyidx + -3]->minor['smarty_internal_index']));
    }
#line 395 "./lexer/smarty_internal_templateparser.y"
    function yy_r31(){
    $tag = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->lex->ldel_length, -$this->lex->rdel_length));
    if ($tag == 'strip') {
        $this->strip = true;
        $this->_retvalue = null;;
    } else {
        if (defined($tag)) {
            if ($this->security) {
               $this->security->isTrustedConstant($tag, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compileTag('private_print_expression',array(),array('value'=>$tag));
        } else {
            if (preg_match('/^(.*)(\s+nocache)$/', $tag, $match)) {
                $this->_retvalue = $this->compiler->compileTag($match[1],array("'nocache'"));
            } else {
                $this->_retvalue = $this->compiler->compileTag($tag,array());
            }
        }
    }
    }
#line 417 "./lexer/smarty_internal_templateparser.y"
    function yy_r32(){
        if (defined($this->yystack[$this->yyidx + -1]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + -1]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compileTag('private_print_expression',$this->yystack[$this->yyidx + 0]->minor,array('value'=>$this->yystack[$this->yyidx + -1]->minor));
        } else {
            $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);
        }
    }
#line 427 "./lexer/smarty_internal_templateparser.y"
    function yy_r33(){
        if (defined($this->yystack[$this->yyidx + 0]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compileTag('private_print_expression',array(),array('value'=>$this->yystack[$this->yyidx + 0]->minor));
        } else {
            $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + 0]->minor,array());
        }
    }
#line 440 "./lexer/smarty_internal_templateparser.y"
    function yy_r34(){
        if (defined($this->yystack[$this->yyidx + -2]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + -2]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compileTag('private_print_expression',$this->yystack[$this->yyidx + 0]->minor,array('value'=>$this->yystack[$this->yyidx + -2]->minor, 'modifierlist'=>$this->yystack[$this->yyidx + -1]->minor));
        } else {
            $this->_retvalue = '<?php ob_start();?>'.$this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor,$this->yystack[$this->yyidx + 0]->minor).'<?php echo ';
            $this->_retvalue .= $this->compiler->compileTag('private_modifier',array(),array('modifierlist'=>$this->yystack[$this->yyidx + -1]->minor,'value'=>'ob_get_clean()')).';?>';
        }
    }
#line 453 "./lexer/smarty_internal_templateparser.y"
    function yy_r35(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor,$this->yystack[$this->yyidx + 0]->minor,array('object_method'=>$this->yystack[$this->yyidx + -1]->minor));
    }
#line 458 "./lexer/smarty_internal_templateparser.y"
    function yy_r36(){
    $this->_retvalue = '<?php ob_start();?>'.$this->compiler->compileTag($this->yystack[$this->yyidx + -4]->minor,$this->yystack[$this->yyidx + 0]->minor,array('object_method'=>$this->yystack[$this->yyidx + -2]->minor)).'<?php echo ';
    $this->_retvalue .= $this->compiler->compileTag('private_modifier',array(),array('modifierlist'=>$this->yystack[$this->yyidx + -1]->minor,'value'=>'ob_get_clean()')).';?>';
    }
#line 464 "./lexer/smarty_internal_templateparser.y"
    function yy_r37(){
    $tag = trim(substr($this->yystack[$this->yyidx + -1]->minor,$this->lex->ldel_length)); 
    $this->_retvalue = $this->compiler->compileTag(($tag == 'else if')? 'elseif' : $tag,array(),array('if condition'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 469 "./lexer/smarty_internal_templateparser.y"
    function yy_r38(){
    $tag = trim(substr($this->yystack[$this->yyidx + -2]->minor,$this->lex->ldel_length));
    $this->_retvalue = $this->compiler->compileTag(($tag == 'else if')? 'elseif' : $tag,$this->yystack[$this->yyidx + 0]->minor,array('if condition'=>$this->yystack[$this->yyidx + -1]->minor));
    }
#line 474 "./lexer/smarty_internal_templateparser.y"
    function yy_r39(){
    $tag = trim(substr($this->yystack[$this->yyidx + -1]->minor,$this->lex->ldel_length));
    $this->_retvalue = $this->compiler->compileTag(($tag == 'else if')? 'elseif' : $tag,array(),array('if condition'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 485 "./lexer/smarty_internal_templateparser.y"
    function yy_r41(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -6]->minor),array('ifexp'=>$this->yystack[$this->yyidx + -4]->minor),array('var'=>$this->yystack[$this->yyidx + -2]->minor),array('step'=>$this->yystack[$this->yyidx + -1]->minor))),1);
    }
#line 489 "./lexer/smarty_internal_templateparser.y"
    function yy_r42(){
    $this->_retvalue = '='.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 497 "./lexer/smarty_internal_templateparser.y"
    function yy_r44(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -3]->minor),array('to'=>$this->yystack[$this->yyidx + -1]->minor))),0);
    }
#line 501 "./lexer/smarty_internal_templateparser.y"
    function yy_r45(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -5]->minor),array('to'=>$this->yystack[$this->yyidx + -3]->minor),array('step'=>$this->yystack[$this->yyidx + -1]->minor))),0);
    }
#line 506 "./lexer/smarty_internal_templateparser.y"
    function yy_r46(){
    $this->_retvalue = $this->compiler->compileTag('foreach',$this->yystack[$this->yyidx + 0]->minor);
    }
#line 511 "./lexer/smarty_internal_templateparser.y"
    function yy_r47(){
    $this->_retvalue = $this->compiler->compileTag('foreach',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('from'=>$this->yystack[$this->yyidx + -3]->minor),array('item'=>$this->yystack[$this->yyidx + -1]->minor))));
    }
#line 515 "./lexer/smarty_internal_templateparser.y"
    function yy_r48(){
    $this->_retvalue = $this->compiler->compileTag('foreach',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('from'=>$this->yystack[$this->yyidx + -5]->minor),array('item'=>$this->yystack[$this->yyidx + -1]->minor),array('key'=>$this->yystack[$this->yyidx + -3]->minor))));
    }
#line 528 "./lexer/smarty_internal_templateparser.y"
    function yy_r51(){
    $this->_retvalue = $this->compiler->compileTag('setfilter',array(),array('modifier_list'=>array(array_merge(array($this->yystack[$this->yyidx + -1]->minor),$this->yystack[$this->yyidx + 0]->minor))));
    }
#line 532 "./lexer/smarty_internal_templateparser.y"
    function yy_r52(){
    $this->_retvalue = $this->compiler->compileTag('setfilter',array(),array('modifier_list'=>array_merge(array(array_merge(array($this->yystack[$this->yyidx + -2]->minor),$this->yystack[$this->yyidx + -1]->minor)),$this->yystack[$this->yyidx + 0]->minor)));
    }
#line 537 "./lexer/smarty_internal_templateparser.y"
    function yy_r53(){
    $j = strrpos($this->yystack[$this->yyidx + 0]->minor,'.');
    if ($this->yystack[$this->yyidx + 0]->minor[$j+1] == 'c') {
        // {$smarty.block.child}
        $this->_retvalue = SMARTY_INTERNAL_COMPILE_BLOCK::compileChildBlock($this->compiler);
    } else {
        // {$smarty.block.parent}
        $this->_retvalue = SMARTY_INTERNAL_COMPILE_BLOCK::compileParentBlock($this->compiler);
    }
    }
#line 550 "./lexer/smarty_internal_templateparser.y"
    function yy_r54(){
    $tag = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->lex->ldel_length, -$this->lex->rdel_length), ' /');
    if ($tag == 'strip') {
        $this->strip = false;
        $this->_retvalue = null;
    } else {
       $this->_retvalue = $this->compiler->compileTag($tag.'close',array());
    }
     }
#line 559 "./lexer/smarty_internal_templateparser.y"
    function yy_r55(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + 0]->minor.'close',array());
    }
#line 563 "./lexer/smarty_internal_templateparser.y"
    function yy_r56(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -1]->minor.'close',array(),array('modifier_list'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 568 "./lexer/smarty_internal_templateparser.y"
    function yy_r57(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor.'close',array(),array('object_method'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 572 "./lexer/smarty_internal_templateparser.y"
    function yy_r58(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor.'close',array(),array('object_method'=>$this->yystack[$this->yyidx + -1]->minor, 'modifier_list'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 580 "./lexer/smarty_internal_templateparser.y"
    function yy_r59(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    $this->_retvalue[] = $this->yystack[$this->yyidx + 0]->minor;
    }
#line 586 "./lexer/smarty_internal_templateparser.y"
    function yy_r60(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor);
    }
#line 591 "./lexer/smarty_internal_templateparser.y"
    function yy_r61(){
    $this->_retvalue = array();
    }
#line 596 "./lexer/smarty_internal_templateparser.y"
    function yy_r62(){
    if (defined($this->yystack[$this->yyidx + 0]->minor)) {
        if ($this->security) {
            $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
        }
        $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>$this->yystack[$this->yyidx + 0]->minor);
    } else {
        $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>'\''.$this->yystack[$this->yyidx + 0]->minor.'\'');
    }
    }
#line 607 "./lexer/smarty_internal_templateparser.y"
    function yy_r63(){
    $this->_retvalue = array(trim($this->yystack[$this->yyidx + -1]->minor," =\n\r\t")=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 615 "./lexer/smarty_internal_templateparser.y"
    function yy_r65(){
    $this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';
    }
#line 627 "./lexer/smarty_internal_templateparser.y"
    function yy_r68(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 640 "./lexer/smarty_internal_templateparser.y"
    function yy_r70(){
    $this->yystack[$this->yyidx + -2]->minor[]=$this->yystack[$this->yyidx + 0]->minor;
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor;
    }
#line 645 "./lexer/smarty_internal_templateparser.y"
    function yy_r71(){
    $this->_retvalue = array('var' => '\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'\'', 'value'=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 652 "./lexer/smarty_internal_templateparser.y"
    function yy_r73(){
    $this->_retvalue = array('var' => $this->yystack[$this->yyidx + -2]->minor, 'value'=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 676 "./lexer/smarty_internal_templateparser.y"
    function yy_r77(){
    $this->_retvalue = '$_smarty_tpl->getStreamVariable(\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'://' . $this->yystack[$this->yyidx + 0]->minor . '\')';
    }
#line 681 "./lexer/smarty_internal_templateparser.y"
    function yy_r78(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor . trim($this->yystack[$this->yyidx + -1]->minor) . $this->yystack[$this->yyidx + 0]->minor;
    }
#line 695 "./lexer/smarty_internal_templateparser.y"
    function yy_r81(){
    $this->_retvalue = $this->compiler->compileTag('private_modifier',array(),array('value'=>$this->yystack[$this->yyidx + -1]->minor,'modifierlist'=>$this->yystack[$this->yyidx + 0]->minor));
    }
#line 701 "./lexer/smarty_internal_templateparser.y"
    function yy_r82(){
    $this->_retvalue = (isset($this->yystack[$this->yyidx + -1]->minor['pre']) ? $this->yystack[$this->yyidx + -1]->minor['pre'] : '') . $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor['op'].$this->yystack[$this->yyidx + 0]->minor . (isset($this->yystack[$this->yyidx + -1]->minor['pre']) ? ')' : '');
    }
#line 704 "./lexer/smarty_internal_templateparser.y"
    function yy_r83(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor . $this->yystack[$this->yyidx + -1]->minor . ')';
    }
#line 708 "./lexer/smarty_internal_templateparser.y"
    function yy_r84(){
    $this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor.')';
    }
#line 712 "./lexer/smarty_internal_templateparser.y"
    function yy_r85(){
    $this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.',(array)'.$this->yystack[$this->yyidx + 0]->minor.')';
    }
#line 716 "./lexer/smarty_internal_templateparser.y"
    function yy_r86(){
      $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 728 "./lexer/smarty_internal_templateparser.y"
    function yy_r88(){
    $this->_retvalue = $this->yystack[$this->yyidx + -5]->minor.' ? '. $this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'\'') . ' : '.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 732 "./lexer/smarty_internal_templateparser.y"
    function yy_r89(){
    $this->_retvalue = $this->yystack[$this->yyidx + -5]->minor.' ? '.$this->yystack[$this->yyidx + -2]->minor.' : '.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 747 "./lexer/smarty_internal_templateparser.y"
    function yy_r92(){
    $this->_retvalue = '!'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 768 "./lexer/smarty_internal_templateparser.y"
    function yy_r97(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 772 "./lexer/smarty_internal_templateparser.y"
    function yy_r98(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.'.';
    }
#line 776 "./lexer/smarty_internal_templateparser.y"
    function yy_r99(){
    $this->_retvalue = '.'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 781 "./lexer/smarty_internal_templateparser.y"
    function yy_r100(){
    if (defined($this->yystack[$this->yyidx + 0]->minor)) {
        if ($this->security) {
             $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
        }
        $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
    } else {
        $this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';
    }
    }
#line 798 "./lexer/smarty_internal_templateparser.y"
    function yy_r102(){
    $this->_retvalue = "(". $this->yystack[$this->yyidx + -1]->minor .")";
    }
#line 813 "./lexer/smarty_internal_templateparser.y"
    function yy_r105(){
    self::$prefix_number++;
    if ($this->yystack[$this->yyidx + -2]->minor['var'] == '\'smarty\'') {
        $this->compiler->prefix_code[] = '<?php $_tmp'.self::$prefix_number.' = '. $this->compiler->compileTag('private_special_variable',array(),$this->yystack[$this->yyidx + -2]->minor['smarty_internal_index']).';?>';
     } else {
        $this->compiler->prefix_code[] = '<?php $_tmp'.self::$prefix_number.' = '. $this->compiler->compileVariable($this->yystack[$this->yyidx + -2]->minor['var']).$this->yystack[$this->yyidx + -2]->minor['smarty_internal_index'].';?>';
    }
    $this->_retvalue = '$_tmp'.self::$prefix_number.'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
    }
#line 824 "./lexer/smarty_internal_templateparser.y"
    function yy_r106(){
   self::$prefix_number++;
    $tmp = $this->compiler->appendCode('<?php ob_start();?>', $this->yystack[$this->yyidx + 0]->minor);
    $this->compiler->prefix_code[] = $this->compiler->appendCode($tmp, '<?php $_tmp'.self::$prefix_number.'=ob_get_clean();?>');
    $this->_retvalue = '$_tmp'.self::$prefix_number;
    }
#line 841 "./lexer/smarty_internal_templateparser.y"
    function yy_r109(){
    if (!in_array(strtolower($this->yystack[$this->yyidx + -2]->minor), array('self', 'parent')) && (!$this->security || $this->security->isTrustedStaticClassAccess($this->yystack[$this->yyidx + -2]->minor, $this->yystack[$this->yyidx + 0]->minor, $this->compiler))) {
        if (isset($this->smarty->registered_classes[$this->yystack[$this->yyidx + -2]->minor])) {
            $this->_retvalue = $this->smarty->registered_classes[$this->yystack[$this->yyidx + -2]->minor].'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
        } else {
            $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
        } 
    } else {
        $this->compiler->trigger_template_error ("static class '".$this->yystack[$this->yyidx + -2]->minor."' is undefined or not allowed by security setting");
    }
    }
#line 860 "./lexer/smarty_internal_templateparser.y"
    function yy_r111(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
        }
#line 871 "./lexer/smarty_internal_templateparser.y"
    function yy_r112(){
   $this->_retvalue = $this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'');
    }
#line 874 "./lexer/smarty_internal_templateparser.y"
    function yy_r113(){
    if ($this->yystack[$this->yyidx + 0]->minor['var'] == '\'smarty\'') {
        $smarty_var = $this->compiler->compileTag('private_special_variable',array(),$this->yystack[$this->yyidx + 0]->minor['smarty_internal_index']);
        $this->_retvalue = $smarty_var;
    } else {
        // used for array reset,next,prev,end,current 
        $this->last_variable = $this->yystack[$this->yyidx + 0]->minor['var'];
        $this->last_index = $this->yystack[$this->yyidx + 0]->minor['smarty_internal_index'];
        $this->_retvalue = $this->compiler->compileVariable($this->yystack[$this->yyidx + 0]->minor['var']).$this->yystack[$this->yyidx + 0]->minor['smarty_internal_index'];
    }
    }
#line 887 "./lexer/smarty_internal_templateparser.y"
    function yy_r114(){
    $this->_retvalue = '$_smarty_tpl->tpl_vars['. $this->yystack[$this->yyidx + -2]->minor .']->'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 897 "./lexer/smarty_internal_templateparser.y"
    function yy_r116(){
    $this->_retvalue = $this->compiler->compileConfigVariable("'" . $this->yystack[$this->yyidx + -1]->minor . "'");
    }
#line 901 "./lexer/smarty_internal_templateparser.y"
    function yy_r117(){
    $this->_retvalue = '(is_array($tmp = ' . $this->compiler->compileConfigVariable("'" . $this->yystack[$this->yyidx + -2]->minor . "'") . ') ? $tmp'.$this->yystack[$this->yyidx + 0]->minor.' :null)';
    }
#line 905 "./lexer/smarty_internal_templateparser.y"
    function yy_r118(){
    $this->_retvalue = $this->compiler->compileConfigVariable($this->yystack[$this->yyidx + -1]->minor);
    }
#line 909 "./lexer/smarty_internal_templateparser.y"
    function yy_r119(){
    $this->_retvalue = '(is_array($tmp = ' . $this->compiler->compileConfigVariable($this->yystack[$this->yyidx + -2]->minor) . ') ? $tmp'.$this->yystack[$this->yyidx + 0]->minor.' : null)';
    }
#line 913 "./lexer/smarty_internal_templateparser.y"
    function yy_r120(){
    $this->_retvalue = array('var'=>'\''.substr($this->yystack[$this->yyidx + -1]->minor,1).'\'', 'smarty_internal_index'=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 916 "./lexer/smarty_internal_templateparser.y"
    function yy_r121(){
    $this->_retvalue = array('var'=>$this->yystack[$this->yyidx + -1]->minor, 'smarty_internal_index'=>$this->yystack[$this->yyidx + 0]->minor);
    }
#line 929 "./lexer/smarty_internal_templateparser.y"
    function yy_r123(){
    return;
    }
#line 935 "./lexer/smarty_internal_templateparser.y"
    function yy_r124(){
    $this->_retvalue = '['.$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'').']';
    }
#line 938 "./lexer/smarty_internal_templateparser.y"
    function yy_r125(){
    $this->_retvalue = '['.$this->compiler->compileVariable($this->yystack[$this->yyidx + 0]->minor).']';
    }
#line 942 "./lexer/smarty_internal_templateparser.y"
    function yy_r126(){
    $this->_retvalue = '['.$this->compiler->compileVariable($this->yystack[$this->yyidx + -2]->minor).'->'.$this->yystack[$this->yyidx + 0]->minor.']';
    }
#line 946 "./lexer/smarty_internal_templateparser.y"
    function yy_r127(){
    if (defined($this->yystack[$this->yyidx + 0]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
            }
            $this->_retvalue = '['. $this->yystack[$this->yyidx + 0]->minor .']';
        } else {
            $this->_retvalue = "['". $this->yystack[$this->yyidx + 0]->minor ."']";
        }
    }
#line 957 "./lexer/smarty_internal_templateparser.y"
    function yy_r128(){
    $this->_retvalue = '['. $this->yystack[$this->yyidx + 0]->minor .']';
    }
#line 962 "./lexer/smarty_internal_templateparser.y"
    function yy_r129(){
    $this->_retvalue = '['. $this->yystack[$this->yyidx + -1]->minor .']';
    }
#line 967 "./lexer/smarty_internal_templateparser.y"
    function yy_r130(){
    $this->_retvalue = '['.$this->compiler->compileTag('private_special_variable',array(),'[\'section\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\'][\'index\']').']';
    }
#line 971 "./lexer/smarty_internal_templateparser.y"
    function yy_r131(){
    $this->_retvalue = '['.$this->compiler->compileTag('private_special_variable',array(),'[\'section\'][\''.$this->yystack[$this->yyidx + -3]->minor.'\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\']').']';
    }
#line 974 "./lexer/smarty_internal_templateparser.y"
    function yy_r132(){
    $this->_retvalue = '['.$this->yystack[$this->yyidx + -1]->minor.']';
    }
#line 980 "./lexer/smarty_internal_templateparser.y"
    function yy_r134(){
    $this->_retvalue = '['.$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -1]->minor,1).'\'').']';;
    }
#line 996 "./lexer/smarty_internal_templateparser.y"
    function yy_r138(){
    $this->_retvalue = '[]';
    }
#line 1006 "./lexer/smarty_internal_templateparser.y"
    function yy_r139(){
    $this->_retvalue = '\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'';
    }
#line 1010 "./lexer/smarty_internal_templateparser.y"
    function yy_r140(){
    $this->_retvalue = "''";
    }
#line 1015 "./lexer/smarty_internal_templateparser.y"
    function yy_r141(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1023 "./lexer/smarty_internal_templateparser.y"
    function yy_r143(){
    $var = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->lex->ldel_length, -$this->lex->rdel_length), ' $');
    $this->_retvalue = $this->compiler->compileVariable('\''.$var.'\'');
    }
#line 1029 "./lexer/smarty_internal_templateparser.y"
    function yy_r144(){
    $this->_retvalue = '('.$this->yystack[$this->yyidx + -1]->minor.')';
    }
#line 1036 "./lexer/smarty_internal_templateparser.y"
    function yy_r145(){
    if ($this->yystack[$this->yyidx + -1]->minor['var'] == '\'smarty\'') {
        $this->_retvalue =  $this->compiler->compileTag('private_special_variable',array(),$this->yystack[$this->yyidx + -1]->minor['smarty_internal_index']).$this->yystack[$this->yyidx + 0]->minor;
    } else {
        $this->_retvalue = $this->compiler->compileVariable($this->yystack[$this->yyidx + -1]->minor['var']).$this->yystack[$this->yyidx + -1]->minor['smarty_internal_index'].$this->yystack[$this->yyidx + 0]->minor;
    }
    }
#line 1045 "./lexer/smarty_internal_templateparser.y"
    function yy_r146(){
    $this->_retvalue  = $this->yystack[$this->yyidx + 0]->minor;
    }
#line 1050 "./lexer/smarty_internal_templateparser.y"
    function yy_r147(){
    $this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1055 "./lexer/smarty_internal_templateparser.y"
    function yy_r148(){
    if ($this->security && substr($this->yystack[$this->yyidx + -1]->minor,0,1) == '_') {
        $this->compiler->trigger_template_error (self::Err1);
    }
    $this->_retvalue = '->'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1062 "./lexer/smarty_internal_templateparser.y"
    function yy_r149(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::Err2);
    }
    $this->_retvalue = '->{'.$this->compiler->compileVariable($this->yystack[$this->yyidx + -1]->minor).$this->yystack[$this->yyidx + 0]->minor.'}';
    }
#line 1069 "./lexer/smarty_internal_templateparser.y"
    function yy_r150(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::Err2);
    }
    $this->_retvalue = '->{'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';
    }
#line 1076 "./lexer/smarty_internal_templateparser.y"
    function yy_r151(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::Err2);
    }
    $this->_retvalue = '->{\''.$this->yystack[$this->yyidx + -4]->minor.'\'.'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';
    }
#line 1084 "./lexer/smarty_internal_templateparser.y"
    function yy_r152(){
    $this->_retvalue = '->'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1092 "./lexer/smarty_internal_templateparser.y"
    function yy_r153(){
    if (!$this->security || $this->security->isTrustedPhpFunction($this->yystack[$this->yyidx + -3]->minor, $this->compiler)) {
        if (strcasecmp($this->yystack[$this->yyidx + -3]->minor,'isset') === 0 || strcasecmp($this->yystack[$this->yyidx + -3]->minor,'empty') === 0 || strcasecmp($this->yystack[$this->yyidx + -3]->minor,'array') === 0 || is_callable($this->yystack[$this->yyidx + -3]->minor)) {
            $func_name = strtolower($this->yystack[$this->yyidx + -3]->minor);
            if ($func_name == 'isset') {
                if (count($this->yystack[$this->yyidx + -1]->minor) == 0) {
                    $this->compiler->trigger_template_error ('Illegal number of paramer in "isset()"');
                }
                $par = implode(',',$this->yystack[$this->yyidx + -1]->minor);
                if (strncasecmp($par,'$_smarty_tpl->smarty->ext->_config->_getConfigVariable',strlen('$_smarty_tpl->smarty->ext->_config->_getConfigVariable')) === 0) {
                    self::$prefix_number++;
                    $this->compiler->prefix_code[] = '<?php $_tmp'.self::$prefix_number.'='.str_replace(')',', false)',$par).';?>';
                    $isset_par = '$_tmp'.self::$prefix_number;
                } else {
                    $isset_par=str_replace("')->value","',null,true,false)->value",$par);
                }
                $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . "(". $isset_par .")";
            } elseif (in_array($func_name,array('empty','reset','current','end','prev','next'))){
                if (count($this->yystack[$this->yyidx + -1]->minor) != 1) {
                    $this->compiler->trigger_template_error ('Illegal number of paramer in "empty()"');
                }
                if ($func_name == 'empty') {
                    $this->_retvalue = $func_name.'('.str_replace("')->value","',null,true,false)->value",$this->yystack[$this->yyidx + -1]->minor[0]).')';
                } else {
                    $this->_retvalue = $func_name.'('.$this->yystack[$this->yyidx + -1]->minor[0].')';
                }
            } else {
                $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . "(". implode(',',$this->yystack[$this->yyidx + -1]->minor) .")";
            }
        } else {
            $this->compiler->trigger_template_error ("unknown function \"" . $this->yystack[$this->yyidx + -3]->minor . "\"");
        }
    }
    }
#line 1131 "./lexer/smarty_internal_templateparser.y"
    function yy_r154(){
    if ($this->security && substr($this->yystack[$this->yyidx + -3]->minor,0,1) == '_') {
        $this->compiler->trigger_template_error (self::Err1);
    }
    $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . "(". implode(',',$this->yystack[$this->yyidx + -1]->minor) .")";
    }
#line 1138 "./lexer/smarty_internal_templateparser.y"
    function yy_r155(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::Err2);
    }
    self::$prefix_number++;
    $this->compiler->prefix_code[] = '<?php $_tmp'.self::$prefix_number.'='.$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -3]->minor,1).'\'').';?>';
    $this->_retvalue = '$_tmp'.self::$prefix_number.'('. implode(',',$this->yystack[$this->yyidx + -1]->minor) .')';
    }
#line 1149 "./lexer/smarty_internal_templateparser.y"
    function yy_r156(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -2]->minor,array($this->yystack[$this->yyidx + 0]->minor));
    }
#line 1166 "./lexer/smarty_internal_templateparser.y"
    function yy_r159(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -2]->minor,array(array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor)));
    }
#line 1170 "./lexer/smarty_internal_templateparser.y"
    function yy_r160(){
    $this->_retvalue = array(array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor));
    }
#line 1178 "./lexer/smarty_internal_templateparser.y"
    function yy_r162(){
    $this->_retvalue =  array($this->yystack[$this->yyidx + 0]->minor);
    }
#line 1186 "./lexer/smarty_internal_templateparser.y"
    function yy_r163(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);
    }
#line 1205 "./lexer/smarty_internal_templateparser.y"
    function yy_r167(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor, '', 'method');
    }
#line 1210 "./lexer/smarty_internal_templateparser.y"
    function yy_r168(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -1]->minor, $this->yystack[$this->yyidx + 0]->minor, 'method');
    }
#line 1215 "./lexer/smarty_internal_templateparser.y"
    function yy_r169(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor, '');
    }
#line 1220 "./lexer/smarty_internal_templateparser.y"
    function yy_r170(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -1]->minor, $this->yystack[$this->yyidx + 0]->minor, 'property');
    }
#line 1225 "./lexer/smarty_internal_templateparser.y"
    function yy_r171(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor, $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor, 'property');
    }
#line 1231 "./lexer/smarty_internal_templateparser.y"
    function yy_r172(){
    $this->_retvalue['op'] = ' '. trim($this->yystack[$this->yyidx + 0]->minor) . ' ';
    }
#line 1235 "./lexer/smarty_internal_templateparser.y"
    function yy_r173(){
    static $lops = array(
        'eq' => array('op' => ' == ', 'pre' => null),
        'ne' => array('op' => ' != ', 'pre' => null),
        'neq' => array('op' => ' != ', 'pre' => null),
        'gt' => array('op' => ' > ', 'pre' => null),
        'ge' => array('op' => ' >= ', 'pre' => null),
        'gte' => array('op' => ' >= ', 'pre' => null),
        'lt' => array('op' => ' < ', 'pre' => null),
        'le' => array('op' => ' <= ', 'pre' => null),
        'lte' => array('op' => ' <= ', 'pre' => null),
        'mod' => array('op' => ' % ', 'pre' => null),
        'and' => array('op' => ' && ', 'pre' => null),
        'or' => array('op' => ' || ', 'pre' => null),
        'xor' => array('op' => ' xor ', 'pre' => null),
        'isdivby' => array('op' => ' % ', 'pre' => '!('),
        'isnotdivby' => array('op' => ' % ', 'pre' => '('),
        'isevenby' => array('op' => ' / ', 'pre' => '!(1 & '),
        'isnotevenby' => array('op' => ' / ', 'pre' => '(1 & '),
        'isoddby' => array('op' => ' / ', 'pre' => '(1 & '),
        'isnotoddby' => array('op' => ' / ', 'pre' => '!(1 & '),
        );
    $op = strtolower(preg_replace('/\s*/', '', $this->yystack[$this->yyidx + 0]->minor));
    $this->_retvalue = $lops[$op];
    }
#line 1261 "./lexer/smarty_internal_templateparser.y"
    function yy_r174(){
        static $scond = array (
            'iseven' => '!(1 & ',
            'isnoteven' => '(1 & ',
            'isodd' => '(1 & ',
            'isnotodd' => '!(1 & ',
        );
   $op = strtolower(str_replace(' ', '', $this->yystack[$this->yyidx + 0]->minor));
   $this->_retvalue = $scond[$op];
    }
#line 1275 "./lexer/smarty_internal_templateparser.y"
    function yy_r175(){
    $this->_retvalue = 'array('.$this->yystack[$this->yyidx + -1]->minor.')';
    }
#line 1283 "./lexer/smarty_internal_templateparser.y"
    function yy_r177(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1291 "./lexer/smarty_internal_templateparser.y"
    function yy_r179(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'=>'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1295 "./lexer/smarty_internal_templateparser.y"
    function yy_r180(){ 
    $this->_retvalue = '\''.$this->yystack[$this->yyidx + -2]->minor.'\'=>'.$this->yystack[$this->yyidx + 0]->minor;
    }
#line 1311 "./lexer/smarty_internal_templateparser.y"
    function yy_r183(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor->to_smarty_php($this);
    }
#line 1316 "./lexer/smarty_internal_templateparser.y"
    function yy_r184(){
    $this->yystack[$this->yyidx + -1]->minor->append_subtree($this, $this->yystack[$this->yyidx + 0]->minor);
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    }
#line 1321 "./lexer/smarty_internal_templateparser.y"
    function yy_r185(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Dq($this, $this->yystack[$this->yyidx + 0]->minor);
    }
#line 1325 "./lexer/smarty_internal_templateparser.y"
    function yy_r186(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Code('(string)'.$this->yystack[$this->yyidx + -1]->minor);
    }
#line 1333 "./lexer/smarty_internal_templateparser.y"
    function yy_r188(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Code('(string)$_smarty_tpl->tpl_vars[\''. substr($this->yystack[$this->yyidx + 0]->minor,1) .'\']->value');
    }
#line 1341 "./lexer/smarty_internal_templateparser.y"
    function yy_r190(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Code('(string)('.$this->yystack[$this->yyidx + -1]->minor.')');
    }
#line 1345 "./lexer/smarty_internal_templateparser.y"
    function yy_r191(){
    $this->_retvalue = new Smarty_Internal_ParseTree_Tag($this, $this->yystack[$this->yyidx + 0]->minor);
    }
#line 1349 "./lexer/smarty_internal_templateparser.y"
    function yy_r192(){
    $this->_retvalue = new Smarty_Internal_ParseTree_DqContent($this->yystack[$this->yyidx + 0]->minor);
    }

    private $_retvalue;

    public function yy_reduce($yyruleno)
    {
        if ($this->yyTraceFILE && $yyruleno >= 0
              && $yyruleno < count(self::$yyRuleName)) {
            fprintf($this->yyTraceFILE, "%sReduce (%d) [%s].\n",
                $this->yyTracePrompt, $yyruleno,
                self::$yyRuleName[$yyruleno]);
        }

        $this->_retvalue = $yy_lefthand_side = null;
        if (isset(self::$yyReduceMap[$yyruleno])) {
            // call the action
            $this->_retvalue = null;
            $this->{'yy_r' . self::$yyReduceMap[$yyruleno]}();
            $yy_lefthand_side = $this->_retvalue;
        }
        $yygoto = self::$yyRuleInfo[$yyruleno][0];
        $yysize = self::$yyRuleInfo[$yyruleno][1];
        $this->yyidx -= $yysize;
        for ($i = $yysize; $i; $i--) {
            // pop all of the right-hand side parameters
            array_pop($this->yystack);
        }
        $yyact = $this->yy_find_reduce_action($this->yystack[$this->yyidx]->stateno, $yygoto);
        if ($yyact < self::YYNSTATE) {
            if (!$this->yyTraceFILE && $yysize) {
                $this->yyidx++;
                $x = new TP_yyStackEntry;
                $x->stateno = $yyact;
                $x->major = $yygoto;
                $x->minor = $yy_lefthand_side;
                $this->yystack[$this->yyidx] = $x;
            } else {
                $this->yy_shift($yyact, $yygoto, $yy_lefthand_side);
            }
        } elseif ($yyact == self::YYNSTATE + self::YYNRULE + 1) {
            $this->yy_accept();
        }
    }

    public function yy_parse_failed()
    {
        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sFail!\n", $this->yyTracePrompt);
        } while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
    }

    public function yy_syntax_error($yymajor, $TOKEN)
    {
#line 207 "./lexer/smarty_internal_templateparser.y"

    $this->internalError = true;
    $this->yymajor = $yymajor;
    $this->compiler->trigger_template_error();
    }

    public function yy_accept()
    {
        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sAccept!\n", $this->yyTracePrompt);
        } while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
#line 200 "./lexer/smarty_internal_templateparser.y"

    $this->successful = !$this->internalError;
    $this->internalError = false;
    $this->retvalue = $this->_retvalue;
    }

    public function doParse($yymajor, $yytokenvalue)
    {
        $yyerrorhit = 0;   /* True if yymajor has invoked an error */

        if ($this->yyidx === null || $this->yyidx < 0) {
            $this->yyidx = 0;
            $this->yyerrcnt = -1;
            $x = new TP_yyStackEntry;
            $x->stateno = 0;
            $x->major = 0;
            $this->yystack = array();
            $this->yystack[] = $x;
        }
        $yyendofinput = ($yymajor==0);

        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sInput %s\n",
                $this->yyTracePrompt, $this->yyTokenName[$yymajor]);
        }

        do {
            $yyact = $this->yy_find_shift_action($yymajor);
            if ($yymajor < self::YYERRORSYMBOL &&
                  !$this->yy_is_expected_token($yymajor)) {
                // force a syntax error
                $yyact = self::YY_ERROR_ACTION;
            }
            if ($yyact < self::YYNSTATE) {
                $this->yy_shift($yyact, $yymajor, $yytokenvalue);
                $this->yyerrcnt--;
                if ($yyendofinput && $this->yyidx >= 0) {
                    $yymajor = 0;
                } else {
                    $yymajor = self::YYNOCODE;
                }
            } elseif ($yyact < self::YYNSTATE + self::YYNRULE) {
                $this->yy_reduce($yyact - self::YYNSTATE);
            } elseif ($yyact == self::YY_ERROR_ACTION) {
                if ($this->yyTraceFILE) {
                    fprintf($this->yyTraceFILE, "%sSyntax Error!\n",
                        $this->yyTracePrompt);
                }
                if (self::YYERRORSYMBOL) {
                    if ($this->yyerrcnt < 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $yymx = $this->yystack[$this->yyidx]->major;
                    if ($yymx == self::YYERRORSYMBOL || $yyerrorhit) {
                        if ($this->yyTraceFILE) {
                            fprintf($this->yyTraceFILE, "%sDiscard input token %s\n",
                                $this->yyTracePrompt, $this->yyTokenName[$yymajor]);
                        }
                        $this->yy_destructor($yymajor, $yytokenvalue);
                        $yymajor = self::YYNOCODE;
                    } else {
                        while ($this->yyidx >= 0 &&
                                 $yymx != self::YYERRORSYMBOL &&
        ($yyact = $this->yy_find_shift_action(self::YYERRORSYMBOL)) >= self::YYNSTATE
                              ){
                            $this->yy_pop_parser_stack();
                        }
                        if ($this->yyidx < 0 || $yymajor==0) {
                            $this->yy_destructor($yymajor, $yytokenvalue);
                            $this->yy_parse_failed();
                            $yymajor = self::YYNOCODE;
                        } elseif ($yymx != self::YYERRORSYMBOL) {
                            $u2 = 0;
                            $this->yy_shift($yyact, self::YYERRORSYMBOL, $u2);
                        }
                    }
                    $this->yyerrcnt = 3;
                    $yyerrorhit = 1;
                } else {
                    if ($this->yyerrcnt <= 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $this->yyerrcnt = 3;
                    $this->yy_destructor($yymajor, $yytokenvalue);
                    if ($yyendofinput) {
                        $this->yy_parse_failed();
                    }
                    $yymajor = self::YYNOCODE;
                }
            } else {
                $this->yy_accept();
                $yymajor = self::YYNOCODE;
            }
        } while ($yymajor != self::YYNOCODE && $this->yyidx >= 0);
    }
}

